********************************************************************************************
*  TITLE:        ZINB Adjusted Model--Delta Method
*
*  PROGRAMMER:   D. Leann Long
*
*  DESCRIPTION:  For the adjusted ZINB model in Wiener, Long & Jurevic, this program
*					reads in the covariance matrix for delta method transformation to
*					obtain variance estimates of overall exposure effect of blood lead
*					(as described in Preisser et al 2012). These overall effects are at
*					the survey mean levels of each extraneous covariate.
*
*  DATE:         02/21/2014
*-----------------------------------------------------------------
*  LANGUAGE:     SAS VERSION 9.3
*-----------------------------------------------------------------
*  INPUT:        dft adj cov matrix.csv
*-----------------------------------------------------------------
*  OUTPUT:		 Provides the adjusted mean severity ratios for each increased blood lead 
*					level compared to the < 2 micro-g/dL exposure group
*******************************************************************************************;

/* Importing CSV of Covariance matrix from STATA Output */
PROC IMPORT OUT= WORK.DFT_FULL_COV 
            DATAFILE= "X:\Wiener-Lead & Caries\nhanesiii\dft full cov matrix 20140610.csv" 
            DBMS=CSV REPLACE;
     GETNAMES=YES;
     DATAROW=2; 
RUN;

data dft_stata_parm_est; /* Providing the point estimates for variables in Mean Severity Ratio calculation */
	input m_lead_cat2 m_lead_cat3 m_lead_cat4 
			m_male m_black m_mexam m_o_race m_age_3 
			  m_age_4 m_age_5 m_rural m_reg_mw m_reg_s m_reg_w
			  m_bel_pov m_less_hs m_more_hs m_smoke m_low_bw m_high_bw
			  m_breastf m_bd m_cond_vg_g m_cond_f_p m_int
			zi_lead_cat2 zi_lead_cat3 zi_lead_cat4 zi_male zi_black
			zi_mexam zi_o_race zi_age_3 zi_age_4 zi_age_5 zi_rural zi_reg_s zi_reg_w zi_reg_mw zi_bel_pov zi_less_hs
			zi_more_hs zi_smoke zi_low_bw zi_high_bw zi_breastf zi_bd zi_cond_vg_g zi_cond_f_p zi_int;
	cards;
.2967398 .545065 .403173 -.0188523 -.119543 .0189759 .4126355 .3986222 .2089399 .539383 .0795562 .2848215 .1840473 .0180256 -.1561861 -.0400825 -.1752111 -.021033 .1619832  
-.0665464 .1559249 .1174341 .3550207 .9947431 -.2101485
-.3895044 -.2642838 -.2982002 .1840316 -.6267633 -.8676388 -.6584342 -.9464906 -1.641813 -2.000971 -.3082357 .1736557 -.3563032 .1105721 -.3319446 .0048626 -.1128464   
-.7697819 .5285597 .2003959 .0414294 -.3995509 -1.247165 -3.457038 4.64588
;
run;

libname caries "X:\Wiener-Lead & Caries\nhanesiii";
proc surveymeans data=caries.merge_dental_lab_20140610;	/* Reading in NHANES III Data for Averaging over Survey Means of Extraneous Covariates */
	ods select NONE;
	domain eligible;
	strata sdpstra6;
	cluster sdppsu6;
	weight wtpfex6;
	var lead_cat2 lead_cat3 lead_cat4 male black mexam o_race age_3 age_4 age_5 rural reg_mw reg_s reg_w bel_pov less_hs more_hs smoke
			low_bw high_bw breastf been_dent cond_vg_g cond_f_p;
	ods output Domain=stats;
run;

data survey_means; /* Converting SURVEYMEANS output into useable SAS dataset for Averaging over Survey Means of Extraneous Covariates */
	set stats end=lastrec;
	if eligible = 1;

	retain mean_lead2 mean_lead3 mean_lead4 mean_male mean_black mean_mexam mean_o_race mean_age_3 mean_age_4 mean_age_5 mean_rural mean_reg_mw 
			mean_reg_s mean_reg_w mean_bel_pov mean_less_hs mean_more_hs mean_smoke mean_low_bw mean_high_bw
			mean_breastf mean_new_bd mean_cond_vg_g mean_cond_f_p 0;

	if varname = 'lead_cat2' 	then mean_lead2		= mean;
	if varname = 'lead_cat3' 	then mean_lead3		= mean;
	if varname = 'lead_cat4' 	then mean_lead4		= mean;
	if varname = 'male' 		then mean_male 		= mean;
	if varname = 'black' 		then mean_black 	= mean;
	if varname = 'mexam' 		then mean_mexam 	= mean;
	if varname = 'o_race' 		then mean_o_race 	= mean;
	if varname = 'age_3' 		then mean_age_3 	= mean;
	if varname = 'age_4' 		then mean_age_4 	= mean;
	if varname = 'age_5' 		then mean_age_5 	= mean;
	if varname = 'rural' 		then mean_rural 	= mean;
	if varname = 'reg_mw' 		then mean_reg_mw 	= mean;
	if varname = 'reg_s' 		then mean_reg_s 	= mean;
	if varname = 'reg_w' 		then mean_reg_w 	= mean;
	if varname = 'bel_pov' 		then mean_bel_pov 	= mean;
	if varname = 'less_hs' 		then mean_less_hs 	= mean;
	if varname = 'more_hs' 		then mean_more_hs 	= mean;
	if varname = 'smoke' 		then mean_smoke 	= mean;
	if varname = 'low_bw' 		then mean_low_bw 	= mean;
	if varname = 'high_bw' 		then mean_high_bw 	= mean;
	if varname = 'breastf' 		then mean_breastf 	= mean;
	if varname = 'been_dent'	then mean_new_bd	= mean;
	if varname = 'cond_vg_g'	then mean_cond_vg_g	= mean;
	if varname = 'cond_f_p'		then mean_cond_f_p	= mean;

	keep mean_lead2 mean_lead3 mean_lead4 mean_male mean_black mean_mexam mean_o_race mean_age_3 mean_age_4 mean_age_5 mean_rural mean_reg_mw 
			mean_reg_s mean_reg_w mean_bel_pov mean_less_hs mean_more_hs mean_smoke mean_low_bw  mean_high_bw
			mean_breastf mean_new_bd mean_cond_vg_g mean_cond_f_p;

	if lastrec then output;
run;
proc contents data=dft_full_cov;run;


ods pdf file="X:\Wiener-Lead & Caries\nhanesiii\IRR All Covs.pdf";
title "Lead & Caries Primary Analysis";
ods select ALL;
proc iml worksize = 30000 symsize = 1000;

reset noprint noname fuzz;

	use DFT_FULL_COV;

	read all var {depdftdc_lead_cat2 depdftdc_lead_cat3	depdftdc_lead_cat4 depdftdc_male depdftdc_black depdftdc_mexam	depdftdc_o_race depdftdc_age_3 depdftdc_age_4
				 depdftdc_age_5 depdftdc_rural depdftdc_reg_s depdftdc_reg_w depdftdc_reg_mw depdftdc_bel_pov depdftdc_less_hs	
				 depdftdc_more_hs depdftdc_smoke depdftdc_low_bw depdftdc_high_bw depdftdc_breastf depdftdc_been_dent depdftdc_cond_vg_g depdftdc_cond_f_p depdftdc__cons
				 inflate_lead_cat2 inflate_lead_cat3
				 inflate_lead_cat4 inflate_male inflate_black inflate_mexam	inflate_o_race inflate_age_3 inflate_age_4
				 inflate_age_5 inflate_rural inflate_reg_s inflate_reg_w inflate_reg_mw	inflate_bel_pov	inflate_less_hs	
				 inflate_more_hs inflate_smoke inflate_low_bw inflate_high_bw inflate_breastf inflate_been_dent inflate_cond_vg_g inflate_cond_f_p inflate__cons lnalpha__cons} into covar;

	close DFT_FULL_COV;

	use survey_means;
	read all var{mean_lead2} into mean_lead2;
	read all var{mean_lead3} into mean_lead3;
	read all var{mean_lead4} into mean_lead4;
	read all var{mean_male} into mean_male;
	read all var{mean_black} into mean_black;
	read all var{mean_mexam} into mean_mexam;
	read all var{mean_o_race} into mean_o_race;
	read all var{mean_age_3} into mean_age_3;
	read all var{mean_age_4} into mean_age_4;
	read all var{mean_age_5} into mean_age_5;
	read all var{mean_rural} into mean_rural;
	read all var{mean_reg_mw} into mean_reg_mw;
	read all var{mean_reg_s} into mean_reg_s;
	read all var{mean_reg_w} into mean_reg_w;
	read all var{mean_bel_pov} into mean_bel_pov;
	read all var{mean_less_hs} into mean_less_hs;
	read all var{mean_more_hs} into mean_more_hs;
	read all var{mean_smoke} into mean_smoke;
	read all var{mean_low_bw} into mean_low_bw;
	read all var{mean_high_bw} into mean_high_bw;
	read all var{mean_breastf} into mean_breastf;
	read all var{mean_new_bd} into mean_new_bd;
	read all var{mean_cond_vg_g} into mean_cond_vg_g;
	read all var{mean_cond_f_p} into mean_cond_f_p;
	close survey_means;

	use dft_stata_parm_est;
	*read all var {prm2 prm4 prm5 prm6} into covar;
	read all var {m_lead_cat2} into m_lead_cat2;
	read all var {m_lead_cat3} into m_lead_cat3;
	read all var {m_lead_cat4} into m_lead_cat4;
	read all var {m_int} into m_int;
	read all var {m_male} into m_male;
	read all var {m_black} into m_black;
	read all var {m_mexam} into m_mexam;
	read all var {m_o_race} into m_o_race;
	read all var {m_age_3} into m_age_3;
	read all var {m_age_4} into m_age_4;
	read all var {m_age_5} into m_age_5;
	read all var {m_rural} into m_rural;
	read all var {m_reg_mw} into m_reg_mw;
	read all var {m_reg_s} into m_reg_s;
	read all var {m_reg_w} into m_reg_w;
	read all var {m_bel_pov} into m_bel_pov;
	read all var {m_less_hs} into m_less_hs;
	read all var {m_more_hs} into m_more_hs;
	read all var {m_smoke} into m_smoke;
	read all var {m_low_bw} into m_low_bw;
	read all var {m_high_bw} into m_high_bw;
	read all var {m_breastf} into m_breastf;
	read all var {m_bd} into m_new_bd;
	read all var {m_cond_vg_g} into m_cond_vg_g;
	read all var {m_cond_f_p} into m_cond_f_p;
	read all var {zi_int} into zi_int;
	read all var {zi_lead_cat2} into zi_lead_cat2;
	read all var {zi_lead_cat3} into zi_lead_cat3;
	read all var {zi_lead_cat4} into zi_lead_cat4;
	read all var {zi_male} into zi_male;
	read all var {zi_black} into zi_black;
	read all var {zi_mexam} into zi_mexam;
	read all var {zi_o_race} into zi_o_race;
	read all var {zi_age_3} into zi_age_3;
	read all var {zi_age_4} into zi_age_4;
	read all var {zi_age_5} into zi_age_5;
	read all var {zi_rural} into zi_rural;
	read all var {zi_reg_mw} into zi_reg_mw;
	read all var {zi_reg_s} into zi_reg_s;
	read all var {zi_reg_w} into zi_reg_w;
	read all var {zi_bel_pov} into zi_bel_pov;
	read all var {zi_less_hs} into zi_less_hs;
	read all var {zi_more_hs} into zi_more_hs;
	read all var {zi_smoke} into zi_smoke;
	read all var {zi_low_bw} into zi_low_bw;
	read all var {zi_high_bw} into zi_high_bw;
	read all var {zi_breastf} into zi_breastf;
	read all var {zi_bd} into zi_new_bd;
	read all var {zi_cond_vg_g} into zi_cond_vg_g;
	read all var {zi_cond_f_p} into zi_cond_f_p;
	close dft_stata_parm_est;

	ext_cov_parms_L = J(1,21,0);
	ext_cov_parms_L = zi_male || zi_black || zi_mexam || zi_o_race || zi_age_3 || zi_age_4 || zi_age_5 || zi_rural ||
					zi_reg_mw || zi_reg_s || zi_reg_w || zi_bel_pov || zi_less_hs || zi_more_hs || zi_smoke ||
					zi_low_bw || zi_high_bw || zi_breastf || zi_new_bd || zi_cond_vg_g || zi_cond_f_p;

	ext_cov_value_L = J(1,21,0);
	ext_cov_value_L = mean_male || mean_black || mean_mexam || mean_o_race || mean_age_3 || mean_age_4 || mean_age_5 || mean_rural ||
					mean_reg_mw || mean_reg_s || mean_reg_w || mean_bel_pov || mean_less_hs || mean_more_hs || mean_smoke ||
					mean_low_bw || mean_high_bw || mean_breastf || mean_new_bd || mean_cond_vg_g || mean_cond_f_p;

	ext_cov = ext_cov_parms_L * ext_cov_value_L`;

	g1_log_irr =  m_lead_cat2 + log(1+exp(zi_int+ext_cov)) - log(1+exp(zi_int+ext_cov+zi_lead_cat2));
	g2_log_irr =  m_lead_cat3 + log(1+exp(zi_int+ext_cov)) - log(1+exp(zi_int+ext_cov+zi_lead_cat3));
	g3_log_irr =  m_lead_cat4 + log(1+exp(zi_int+ext_cov)) - log(1+exp(zi_int+ext_cov+zi_lead_cat4));

* G1--Lead_Cat2 vs Lead_Cat1;

	g1_theta = J(1,51,0);

	do i=1 to 25;
		g1_theta[1,i] = 0;
		if i=1 then g1_theta[1,i]=1;
	end;
	g1_theta[1,50] = (exp(zi_int+ext_cov))/((1+exp(zi_int+ext_cov)))-
					(exp(zi_int+ext_cov+zi_lead_cat2)/(1+exp(zi_int+ext_cov+zi_lead_cat2)));
	g1_theta[1,26] = -(exp(zi_int+ext_cov+zi_lead_cat2)/(1+exp(zi_int+ext_cov+zi_lead_cat2)));
	g1_theta[1,27] = 0;
	g1_theta[1,28] = 0;
	g1_theta[1,29] = mean_male		#g1_theta[1,50];
	g1_theta[1,30] = mean_black		#g1_theta[1,50];
	g1_theta[1,31] = mean_mexam		#g1_theta[1,50];
	g1_theta[1,32] = mean_o_race	#g1_theta[1,50];
	g1_theta[1,33] = mean_age_3		#g1_theta[1,50];
	g1_theta[1,34] = mean_age_4		#g1_theta[1,50];
	g1_theta[1,35] = mean_age_5		#g1_theta[1,50];
	g1_theta[1,36] = mean_rural		#g1_theta[1,50];
	g1_theta[1,37] = mean_reg_s		#g1_theta[1,50];
	g1_theta[1,38] = mean_reg_w		#g1_theta[1,50];
	g1_theta[1,39] = mean_reg_mw		#g1_theta[1,50];
	g1_theta[1,40] = mean_bel_pov	#g1_theta[1,50];
	g1_theta[1,41] = mean_less_hs	#g1_theta[1,50];
	g1_theta[1,42] = mean_more_hs	#g1_theta[1,50];
	g1_theta[1,43] = mean_smoke		#g1_theta[1,50];
	g1_theta[1,44] = mean_low_bw	#g1_theta[1,50];
	g1_theta[1,45] = mean_high_bw	#g1_theta[1,50];
	g1_theta[1,46] = mean_breastf	#g1_theta[1,50];
	g1_theta[1,47] = mean_new_bd	#g1_theta[1,50];
	g1_theta[1,48] = mean_cond_vg_g	#g1_theta[1,50];
	g1_theta[1,49] = mean_cond_f_p	#g1_theta[1,50];
	g1_theta[1,51] = 0;

	var_g1 = g1_theta * covar * g1_theta`; 
	se_g1  = sqrt(var_g1);

	g1_irr = exp(g1_log_irr);
	g1_irr_l = exp(g1_log_irr - 1.96*se_g1);
	g1_irr_u = exp(g1_log_irr + 1.96*se_g1);

* G2--Lead_Cat3 vs Lead_Cat1;

	g2_theta = J(1,51,0);

	do i=1 to 25;
		g2_theta[1,i] = 0;
		if i=2 then g2_theta[1,i]=1;
	end;
	g2_theta[1,50] = (exp(zi_int+ext_cov))/((1+exp(zi_int+ext_cov)))-
					(exp(zi_int+ext_cov+zi_lead_cat3)/(1+exp(zi_int+ext_cov+zi_lead_cat3)));
	g2_theta[1,26] = 0;
	g2_theta[1,27] = -(exp(zi_int+ext_cov+zi_lead_cat3)/(1+exp(zi_int+ext_cov+zi_lead_cat3)));
	g2_theta[1,28] = 0;
	g2_theta[1,29] = mean_male		#g2_theta[1,50];
	g2_theta[1,30] = mean_black		#g2_theta[1,50];
	g2_theta[1,31] = mean_mexam		#g2_theta[1,50];
	g2_theta[1,32] = mean_o_race	#g2_theta[1,50];
	g2_theta[1,33] = mean_age_3		#g2_theta[1,50];
	g2_theta[1,34] = mean_age_4		#g2_theta[1,50];
	g2_theta[1,35] = mean_age_5		#g2_theta[1,50];
	g2_theta[1,36] = mean_rural		#g2_theta[1,50];
	g2_theta[1,37] = mean_reg_s 	#g2_theta[1,50];
	g2_theta[1,38] = mean_reg_w		#g2_theta[1,50];
	g2_theta[1,39] = mean_reg_mw	#g2_theta[1,50];
	g2_theta[1,40] = mean_bel_pov	#g2_theta[1,50];
	g2_theta[1,41] = mean_less_hs	#g2_theta[1,50];
	g2_theta[1,42] = mean_more_hs	#g2_theta[1,50];
	g2_theta[1,43] = mean_smoke		#g2_theta[1,50];
	g2_theta[1,44] = mean_low_bw	#g2_theta[1,50];
	g2_theta[1,45] = mean_high_bw	#g2_theta[1,50];
	g2_theta[1,46] = mean_breastf	#g2_theta[1,50];
	g2_theta[1,47] = mean_new_bd	#g2_theta[1,50];
	g2_theta[1,48] = mean_cond_vg_g	#g2_theta[1,50];
	g2_theta[1,49] = mean_cond_f_p	#g2_theta[1,50];
	g2_theta[1,51] = 0;

	var_g2 = g2_theta * covar * g2_theta`; 
	se_g2  = sqrt(var_g2);

	g2_irr = exp(g2_log_irr);
	g2_irr_l = exp(g2_log_irr - 1.96*se_g2);
	g2_irr_u = exp(g2_log_irr + 1.96*se_g2);

* G3--Lead_Cat4 vs Lead_Cat1;

	g3_theta = J(1,51,0);

	do i=1 to 25;
		g3_theta[1,i] = 0;
		if i=3 then g3_theta[1,i]=1;
	end;
	g3_theta[1,50] = (exp(zi_int+ext_cov))/((1+exp(zi_int+ext_cov)))-
					(exp(zi_int+ext_cov+zi_lead_cat4)/(1+exp(zi_int+ext_cov+zi_lead_cat4)));
	g3_theta[1,26] = 0;
	g3_theta[1,27] = 0;
	g3_theta[1,28] = -(exp(zi_int+ext_cov+zi_lead_cat4)/(1+exp(zi_int+ext_cov+zi_lead_cat4)));
	g3_theta[1,29] = mean_male		#g3_theta[1,50];
	g3_theta[1,30] = mean_black		#g3_theta[1,50];
	g3_theta[1,31] = mean_mexam		#g3_theta[1,50];
	g3_theta[1,32] = mean_o_race	#g3_theta[1,50];
	g3_theta[1,33] = mean_age_3		#g3_theta[1,50];
	g3_theta[1,34] = mean_age_4		#g3_theta[1,50];
	g3_theta[1,35] = mean_age_5		#g3_theta[1,50];
	g3_theta[1,36] = mean_rural		#g3_theta[1,50];
	g3_theta[1,37] = mean_reg_s		#g3_theta[1,50];
	g3_theta[1,38] = mean_reg_w		#g3_theta[1,50];
	g3_theta[1,39] = mean_reg_mw	#g3_theta[1,50];
	g3_theta[1,40] = mean_bel_pov	#g3_theta[1,50];
	g3_theta[1,41] = mean_less_hs	#g3_theta[1,50];
	g3_theta[1,42] = mean_more_hs	#g3_theta[1,50];
	g3_theta[1,43] = mean_smoke		#g3_theta[1,50];
	g3_theta[1,44] = mean_low_bw	#g3_theta[1,50];
	g3_theta[1,45] = mean_high_bw	#g3_theta[1,50];
	g3_theta[1,46] = mean_breastf	#g3_theta[1,50];
	g3_theta[1,47] = mean_new_bd	#g3_theta[1,50];
	g3_theta[1,48] = mean_cond_vg_g	#g3_theta[1,50];
	g3_theta[1,49] = mean_cond_f_p	#g3_theta[1,50];
	g3_theta[1,51] = 0;

	var_g3 = g3_theta * covar * g3_theta`; 
	se_g3  = sqrt(var_g3);

	g3_irr = exp(g3_log_irr);
	g3_irr_l = exp(g3_log_irr - 1.96*se_g3);
	g3_irr_u = exp(g3_log_irr + 1.96*se_g3);

* G4--Male vs Female;
ext_cov_parms = J(1,23,0);
	ext_cov_parms = zi_lead_cat2 || zi_lead_cat3 || zi_lead_cat4 || zi_black || zi_mexam || zi_o_race || zi_age_3 || zi_age_4 || zi_age_5 || zi_rural ||
					zi_reg_mw || zi_reg_s || zi_reg_w || zi_bel_pov || zi_less_hs || zi_more_hs || zi_smoke ||
					zi_low_bw || zi_high_bw || zi_breastf || zi_new_bd || zi_cond_vg_g || zi_cond_f_p;

	ext_cov_value = J(1,23,0);
	ext_cov_value = mean_lead2 || mean_lead3 || mean_lead4 || mean_black || mean_mexam || mean_o_race || mean_age_3 || mean_age_4 || mean_age_5 || mean_rural ||
					mean_reg_mw || mean_reg_s || mean_reg_w || mean_bel_pov || mean_less_hs || mean_more_hs || mean_smoke ||
					mean_low_bw || mean_high_bw || mean_breastf || mean_new_bd || mean_cond_vg_g || mean_cond_f_p;

	ext_cov = ext_cov_parms * ext_cov_value`;

	g4_log_irr =  m_male + log(1+exp(zi_int+ext_cov)) - log(1+exp(zi_int+ext_cov+zi_male));
	g4_theta = J(1,51,0);

	do i=1 to 25;
		g4_theta[1,i] = 0;
		if i=4 then g4_theta[1,i]=1;
	end;
	g4_theta[1,50] = (exp(zi_int+ext_cov))/((1+exp(zi_int+ext_cov)))-
					(exp(zi_int+ext_cov+zi_male)/(1+exp(zi_int+ext_cov+zi_male)));
	g4_theta[1,26] = mean_lead2		#g4_theta[1,50];
	g4_theta[1,27] = mean_lead3		#g4_theta[1,50];
	g4_theta[1,28] = mean_lead4		#g4_theta[1,50];
	g4_theta[1,29] = -(exp(zi_int+ext_cov+zi_male)/(1+exp(zi_int+ext_cov+zi_male)));
	g4_theta[1,30] = mean_black		#g4_theta[1,50];
	g4_theta[1,31] = mean_mexam		#g4_theta[1,50];
	g4_theta[1,32] = mean_o_race	#g4_theta[1,50];
	g4_theta[1,33] = mean_age_3		#g4_theta[1,50];
	g4_theta[1,34] = mean_age_4		#g4_theta[1,50];
	g4_theta[1,35] = mean_age_5		#g4_theta[1,50];
	g4_theta[1,36] = mean_rural		#g4_theta[1,50];
	g4_theta[1,37] = mean_reg_s		#g4_theta[1,50];
	g4_theta[1,38] = mean_reg_w		#g4_theta[1,50];
	g4_theta[1,39] = mean_reg_mw	#g4_theta[1,50];
	g4_theta[1,40] = mean_bel_pov	#g4_theta[1,50];
	g4_theta[1,41] = mean_less_hs	#g4_theta[1,50];
	g4_theta[1,42] = mean_more_hs	#g4_theta[1,50];
	g4_theta[1,43] = mean_smoke		#g4_theta[1,50];
	g4_theta[1,44] = mean_low_bw	#g4_theta[1,50];
	g4_theta[1,45] = mean_high_bw	#g4_theta[1,50];
	g4_theta[1,46] = mean_breastf	#g4_theta[1,50];
	g4_theta[1,47] = mean_new_bd	#g4_theta[1,50];
	g4_theta[1,48] = mean_cond_vg_g	#g4_theta[1,50];
	g4_theta[1,49] = mean_cond_f_p	#g4_theta[1,50];
	g4_theta[1,51] = 0;

	var_g4 = g4_theta * covar * g4_theta`; 
	se_g4  = sqrt(var_g4);

	g4_irr = exp(g4_log_irr);
	g4_irr_l = exp(g4_log_irr - 1.96*se_g4);
	g4_irr_u = exp(g4_log_irr + 1.96*se_g4);

* G5--Black vs White;
ext_cov_parms = J(1,21,0);
	ext_cov_parms = zi_lead_cat2 || zi_lead_cat3 || zi_lead_cat4 || zi_male || zi_age_3 || zi_age_4 || zi_age_5 || zi_rural ||
					zi_reg_mw || zi_reg_s || zi_reg_w || zi_bel_pov || zi_less_hs || zi_more_hs || zi_smoke ||
					zi_low_bw || zi_high_bw || zi_breastf || zi_new_bd || zi_cond_vg_g || zi_cond_f_p;

	ext_cov_value = J(1,21,0);
	ext_cov_value = mean_lead2 || mean_lead3 || mean_lead4 || mean_male || mean_age_3 || mean_age_4 || mean_age_5 || mean_rural ||
					mean_reg_mw || mean_reg_s || mean_reg_w || mean_bel_pov || mean_less_hs || mean_more_hs || mean_smoke ||
					mean_low_bw || mean_high_bw || mean_breastf || mean_new_bd || mean_cond_vg_g || mean_cond_f_p;

	ext_cov = ext_cov_parms * ext_cov_value`;

	g5_log_irr =  m_black + log(1+exp(zi_int+ext_cov)) - log(1+exp(zi_int+ext_cov+zi_black));
	g5_theta = J(1,51,0);

	do i=1 to 25;
		g5_theta[1,i] = 0;
		if i=5 then g5_theta[1,i]=1;
	end;
	g5_theta[1,50] = (exp(zi_int+ext_cov))/((1+exp(zi_int+ext_cov)))-
					(exp(zi_int+ext_cov+zi_black)/(1+exp(zi_int+ext_cov+zi_black)));
	g5_theta[1,26] = mean_lead2		#g5_theta[1,50];
	g5_theta[1,27] = mean_lead3		#g5_theta[1,50];
	g5_theta[1,28] = mean_lead4		#g5_theta[1,50];
	g5_theta[1,29] = mean_male		#g5_theta[1,50];
	g5_theta[1,30] = -(exp(zi_int+ext_cov+zi_black)/(1+exp(zi_int+ext_cov+zi_black)));
	g5_theta[1,31] = 0;
	g5_theta[1,32] = 0;
	g5_theta[1,33] = mean_age_3		#g5_theta[1,50];
	g5_theta[1,34] = mean_age_4		#g5_theta[1,50];
	g5_theta[1,35] = mean_age_5		#g5_theta[1,50];
	g5_theta[1,36] = mean_rural		#g5_theta[1,50];
	g5_theta[1,37] = mean_reg_s		#g5_theta[1,50];
	g5_theta[1,38] = mean_reg_w		#g5_theta[1,50];
	g5_theta[1,39] = mean_reg_mw	#g5_theta[1,50];
	g5_theta[1,40] = mean_bel_pov	#g5_theta[1,50];
	g5_theta[1,41] = mean_less_hs	#g5_theta[1,50];
	g5_theta[1,42] = mean_more_hs	#g5_theta[1,50];
	g5_theta[1,43] = mean_smoke		#g5_theta[1,50];
	g5_theta[1,44] = mean_low_bw	#g5_theta[1,50];
	g5_theta[1,45] = mean_high_bw	#g5_theta[1,50];
	g5_theta[1,46] = mean_breastf	#g5_theta[1,50];
	g5_theta[1,47] = mean_new_bd	#g5_theta[1,50];
	g5_theta[1,48] = mean_cond_vg_g	#g5_theta[1,50];
	g5_theta[1,49] = mean_cond_f_p	#g5_theta[1,50];
	g5_theta[1,51] = 0;

	var_g5 = g5_theta * covar * g5_theta`; 
	se_g5  = sqrt(var_g5);

	g5_irr = exp(g5_log_irr);
	g5_irr_l = exp(g5_log_irr - 1.96*se_g5);
	g5_irr_u = exp(g5_log_irr + 1.96*se_g5);

* G6--MexAm vs White;
	ext_cov_parms = J(1,21,0);
	ext_cov_parms = zi_lead_cat2 || zi_lead_cat3 || zi_lead_cat4 || zi_male || zi_age_3 || zi_age_4 || zi_age_5 || zi_rural ||
					zi_reg_mw || zi_reg_s || zi_reg_w || zi_bel_pov || zi_less_hs || zi_more_hs || zi_smoke ||
					zi_low_bw || zi_high_bw || zi_breastf || zi_new_bd || zi_cond_vg_g || zi_cond_f_p;

	ext_cov_value = J(1,21,0);
	ext_cov_value = mean_lead2 || mean_lead3 || mean_lead4 || mean_male || mean_age_3 || mean_age_4 || mean_age_5 || mean_rural ||
					mean_reg_mw || mean_reg_s || mean_reg_w || mean_bel_pov || mean_less_hs || mean_more_hs || mean_smoke ||
					mean_low_bw || mean_high_bw || mean_breastf || mean_new_bd || mean_cond_vg_g || mean_cond_f_p;

	ext_cov = ext_cov_parms * ext_cov_value`;

	g6_log_irr =  m_mexam + log(1+exp(zi_int+ext_cov)) - log(1+exp(zi_int+ext_cov+zi_mexam));
	g6_theta = J(1,51,0);

	do i=1 to 25;
		g6_theta[1,i] = 0;
		if i=6 then g6_theta[1,i]=1;
	end;
	g6_theta[1,50] = (exp(zi_int+ext_cov))/((1+exp(zi_int+ext_cov)))-
					(exp(zi_int+ext_cov+zi_mexam)/(1+exp(zi_int+ext_cov+zi_mexam)));
	g6_theta[1,26] = mean_lead2		#g6_theta[1,50];
	g6_theta[1,27] = mean_lead3		#g6_theta[1,50];
	g6_theta[1,28] = mean_lead4		#g6_theta[1,50];
	g6_theta[1,29] = mean_male		#g6_theta[1,50];
	g6_theta[1,30] = 0;
	g6_theta[1,31] = -(exp(zi_int+ext_cov+zi_mexam)/(1+exp(zi_int+ext_cov+zi_mexam)));
	g6_theta[1,32] = 0;
	g6_theta[1,33] = mean_age_3		#g6_theta[1,50];
	g6_theta[1,34] = mean_age_4		#g6_theta[1,50];
	g6_theta[1,35] = mean_age_5		#g6_theta[1,50];
	g6_theta[1,36] = mean_rural		#g6_theta[1,50];
	g6_theta[1,37] = mean_reg_s		#g6_theta[1,50];
	g6_theta[1,38] = mean_reg_w		#g6_theta[1,50];
	g6_theta[1,39] = mean_reg_mw	#g6_theta[1,50];
	g6_theta[1,40] = mean_bel_pov	#g6_theta[1,50];
	g6_theta[1,41] = mean_less_hs	#g6_theta[1,50];
	g6_theta[1,42] = mean_more_hs	#g6_theta[1,50];
	g6_theta[1,43] = mean_smoke		#g6_theta[1,50];
	g6_theta[1,44] = mean_low_bw	#g6_theta[1,50];
	g6_theta[1,45] = mean_high_bw	#g6_theta[1,50];
	g6_theta[1,46] = mean_breastf	#g6_theta[1,50];
	g6_theta[1,47] = mean_new_bd	#g6_theta[1,50];
	g6_theta[1,48] = mean_cond_vg_g	#g6_theta[1,50];
	g6_theta[1,49] = mean_cond_f_p	#g6_theta[1,50];
	g6_theta[1,51] = 0;

	var_g6 = g6_theta * covar * g6_theta`; 
	se_g6  = sqrt(var_g6);

	g6_irr = exp(g6_log_irr);
	g6_irr_l = exp(g6_log_irr - 1.96*se_g6);
	g6_irr_u = exp(g6_log_irr + 1.96*se_g6);

* G7--Other vs White;
	ext_cov_parms = J(1,21,0);
	ext_cov_parms = zi_lead_cat2 || zi_lead_cat3 || zi_lead_cat4 || zi_male || zi_age_3 || zi_age_4 || zi_age_5 || zi_rural ||
					zi_reg_mw || zi_reg_s || zi_reg_w || zi_bel_pov || zi_less_hs || zi_more_hs || zi_smoke ||
					zi_low_bw || zi_high_bw || zi_breastf || zi_new_bd || zi_cond_vg_g || zi_cond_f_p;

	ext_cov_value = J(1,21,0);
	ext_cov_value = mean_lead2 || mean_lead3 || mean_lead4 || mean_male || mean_age_3 || mean_age_4 || mean_age_5 || mean_rural ||
					mean_reg_mw || mean_reg_s || mean_reg_w || mean_bel_pov || mean_less_hs || mean_more_hs || mean_smoke ||
					mean_low_bw || mean_high_bw || mean_breastf || mean_new_bd || mean_cond_vg_g || mean_cond_f_p;

	ext_cov = ext_cov_parms * ext_cov_value`;

	g7_log_irr =  m_o_race + log(1+exp(zi_int+ext_cov)) - log(1+exp(zi_int+ext_cov+zi_o_race));
	g7_theta = J(1,51,0);

	do i=1 to 25;
		g7_theta[1,i] = 0;
		if i=7 then g7_theta[1,i]=1;
	end;
	g7_theta[1,50] = (exp(zi_int+ext_cov))/((1+exp(zi_int+ext_cov)))-
					(exp(zi_int+ext_cov+zi_o_race)/(1+exp(zi_int+ext_cov+zi_o_race)));
	g7_theta[1,26] = mean_lead2		#g7_theta[1,50];
	g7_theta[1,27] = mean_lead3		#g7_theta[1,50];
	g7_theta[1,28] = mean_lead4		#g7_theta[1,50];
	g7_theta[1,29] = mean_male		#g7_theta[1,50];
	g7_theta[1,30] = 0;
	g7_theta[1,31] = 0;
	g7_theta[1,32] = -(exp(zi_int+ext_cov+zi_o_race)/(1+exp(zi_int+ext_cov+zi_o_race)));
	g7_theta[1,33] = mean_age_3		#g7_theta[1,50];
	g7_theta[1,34] = mean_age_4		#g7_theta[1,50];
	g7_theta[1,35] = mean_age_5		#g7_theta[1,50];
	g7_theta[1,36] = mean_rural		#g7_theta[1,50];
	g7_theta[1,37] = mean_reg_s		#g7_theta[1,50];
	g7_theta[1,38] = mean_reg_w		#g7_theta[1,50];
	g7_theta[1,39] = mean_reg_mw	#g7_theta[1,50];
	g7_theta[1,40] = mean_bel_pov	#g7_theta[1,50];
	g7_theta[1,41] = mean_less_hs	#g7_theta[1,50];
	g7_theta[1,42] = mean_more_hs	#g7_theta[1,50];
	g7_theta[1,43] = mean_smoke		#g7_theta[1,50];
	g7_theta[1,44] = mean_low_bw	#g7_theta[1,50];
	g7_theta[1,45] = mean_high_bw	#g7_theta[1,50];
	g7_theta[1,46] = mean_breastf	#g7_theta[1,50];
	g7_theta[1,47] = mean_new_bd	#g7_theta[1,50];
	g7_theta[1,48] = mean_cond_vg_g	#g7_theta[1,50];
	g7_theta[1,49] = mean_cond_f_p	#g7_theta[1,50];
	g7_theta[1,51] = 0;

	var_g7 = g7_theta * covar * g7_theta`; 
	se_g7  = sqrt(var_g7);

	g7_irr = exp(g7_log_irr);
	g7_irr_l = exp(g7_log_irr - 1.96*se_g7);
	g7_irr_u = exp(g7_log_irr + 1.96*se_g7);

* g8--3 vs 2;
	ext_cov_parms = J(1,21,0);
	ext_cov_parms = zi_lead_cat2 || zi_lead_cat3 || zi_lead_cat4 || zi_male || zi_black || zi_mexam || zi_o_race || zi_rural ||
					zi_reg_mw || zi_reg_s || zi_reg_w || zi_bel_pov || zi_less_hs || zi_more_hs || zi_smoke ||
					zi_low_bw || zi_high_bw || zi_breastf || zi_new_bd || zi_cond_vg_g || zi_cond_f_p;

	ext_cov_value = J(1,21,0);
	ext_cov_value = mean_lead2 || mean_lead3 || mean_lead4 || mean_male || mean_black || mean_mexam || mean_o_race || mean_rural ||
					mean_reg_mw || mean_reg_s || mean_reg_w || mean_bel_pov || mean_less_hs || mean_more_hs || mean_smoke ||
					mean_low_bw || mean_high_bw || mean_breastf || mean_new_bd || mean_cond_vg_g || mean_cond_f_p;

	ext_cov = ext_cov_parms * ext_cov_value`;

	g8_log_irr =  m_age_3 + log(1+exp(zi_int+ext_cov)) - log(1+exp(zi_int+ext_cov+zi_age_3));
	g8_theta = J(1,51,0);

	do i=1 to 25;
		g8_theta[1,i] = 0;
		if i=8 then g8_theta[1,i]=1;
	end;
	g8_theta[1,50] = (exp(zi_int+ext_cov))/((1+exp(zi_int+ext_cov)))-
					(exp(zi_int+ext_cov+zi_age_3)/(1+exp(zi_int+ext_cov+zi_age_3)));
	g8_theta[1,26] = mean_lead2		#g8_theta[1,50];
	g8_theta[1,27] = mean_lead3		#g8_theta[1,50];
	g8_theta[1,28] = mean_lead4		#g8_theta[1,50];
	g8_theta[1,29] = mean_male		#g8_theta[1,50];
	g8_theta[1,30] = mean_black		#g8_theta[1,50];
	g8_theta[1,31] = mean_mexam		#g8_theta[1,50];
	g8_theta[1,32] = mean_o_race	#g8_theta[1,50];
	g8_theta[1,33] = -(exp(zi_int+ext_cov+zi_age_3)/(1+exp(zi_int+ext_cov+zi_age_3)));
	g8_theta[1,34] = 0;
	g8_theta[1,35] = 0;
	g8_theta[1,36] = mean_rural		#g8_theta[1,50];
	g8_theta[1,37] = mean_reg_s		#g8_theta[1,50];
	g8_theta[1,38] = mean_reg_w		#g8_theta[1,50];
	g8_theta[1,39] = mean_reg_mw	#g8_theta[1,50];
	g8_theta[1,40] = mean_bel_pov	#g8_theta[1,50];
	g8_theta[1,41] = mean_less_hs	#g8_theta[1,50];
	g8_theta[1,42] = mean_more_hs	#g8_theta[1,50];
	g8_theta[1,43] = mean_smoke		#g8_theta[1,50];
	g8_theta[1,44] = mean_low_bw	#g8_theta[1,50];
	g8_theta[1,45] = mean_high_bw	#g8_theta[1,50];
	g8_theta[1,46] = mean_breastf	#g8_theta[1,50];
	g8_theta[1,47] = mean_new_bd	#g8_theta[1,50];
	g8_theta[1,48] = mean_cond_vg_g	#g8_theta[1,50];
	g8_theta[1,49] = mean_cond_f_p	#g8_theta[1,50];
	g8_theta[1,51] = 0;

	var_g8 = g8_theta * covar * g8_theta`; 
	se_g8  = sqrt(var_g8);

	g8_irr = exp(g8_log_irr);
	g8_irr_l = exp(g8_log_irr - 1.96*se_g8);
	g8_irr_u = exp(g8_log_irr + 1.96*se_g8);

* g9--4 vs 2;
	ext_cov_parms = J(1,21,0);
	ext_cov_parms = zi_lead_cat2 || zi_lead_cat3 || zi_lead_cat4 || zi_male || zi_black || zi_mexam || zi_o_race || zi_rural ||
					zi_reg_mw || zi_reg_s || zi_reg_w || zi_bel_pov || zi_less_hs || zi_more_hs || zi_smoke ||
					zi_low_bw || zi_high_bw || zi_breastf || zi_new_bd || zi_cond_vg_g || zi_cond_f_p;

	ext_cov_value = J(1,21,0);
	ext_cov_value = mean_lead2 || mean_lead3 || mean_lead4 || mean_male || mean_black || mean_mexam || mean_o_race || mean_rural ||
					mean_reg_mw || mean_reg_s || mean_reg_w || mean_bel_pov || mean_less_hs || mean_more_hs || mean_smoke ||
					mean_low_bw || mean_high_bw || mean_breastf || mean_new_bd || mean_cond_vg_g || mean_cond_f_p;

	ext_cov = ext_cov_parms * ext_cov_value`;

	g9_log_irr =  m_age_4 + log(1+exp(zi_int+ext_cov)) - log(1+exp(zi_int+ext_cov+zi_age_4));
	g9_theta = J(1,51,0);

	do i=1 to 25;
		g9_theta[1,i] = 0;
		if i=9 then g9_theta[1,i]=1;
	end;
	g9_theta[1,50] = (exp(zi_int+ext_cov))/((1+exp(zi_int+ext_cov)))-
					(exp(zi_int+ext_cov+zi_age_4)/(1+exp(zi_int+ext_cov+zi_age_4)));
	g9_theta[1,26] = mean_lead2		#g9_theta[1,50];
	g9_theta[1,27] = mean_lead3		#g9_theta[1,50];
	g9_theta[1,28] = mean_lead4		#g9_theta[1,50];
	g9_theta[1,29] = mean_male		#g9_theta[1,50];
	g9_theta[1,30] = mean_black		#g9_theta[1,50];
	g9_theta[1,31] = mean_mexam		#g9_theta[1,50];
	g9_theta[1,32] = mean_o_race	#g9_theta[1,50];
	g9_theta[1,33] = 0;
	g9_theta[1,34] = -(exp(zi_int+ext_cov+zi_age_4)/(1+exp(zi_int+ext_cov+zi_age_4)));
	g9_theta[1,35] = 0;
	g9_theta[1,36] = mean_rural		#g9_theta[1,50];
	g9_theta[1,37] = mean_reg_s		#g9_theta[1,50];
	g9_theta[1,38] = mean_reg_w		#g9_theta[1,50];
	g9_theta[1,39] = mean_reg_mw	#g9_theta[1,50];
	g9_theta[1,40] = mean_bel_pov	#g9_theta[1,50];
	g9_theta[1,41] = mean_less_hs	#g9_theta[1,50];
	g9_theta[1,42] = mean_more_hs	#g9_theta[1,50];
	g9_theta[1,43] = mean_smoke		#g9_theta[1,50];
	g9_theta[1,44] = mean_low_bw	#g9_theta[1,50];
	g9_theta[1,45] = mean_high_bw	#g9_theta[1,50];
	g9_theta[1,46] = mean_breastf	#g9_theta[1,50];
	g9_theta[1,47] = mean_new_bd	#g9_theta[1,50];
	g9_theta[1,48] = mean_cond_vg_g	#g9_theta[1,50];
	g9_theta[1,49] = mean_cond_f_p	#g9_theta[1,50];
	g9_theta[1,51] = 0;

	var_g9 = g9_theta * covar * g9_theta`; 
	se_g9  = sqrt(var_g9);

	g9_irr = exp(g9_log_irr);
	g9_irr_l = exp(g9_log_irr - 1.96*se_g9);
	g9_irr_u = exp(g9_log_irr + 1.96*se_g9);

* g10--5 vs 2;
	ext_cov_parms = J(1,21,0);
	ext_cov_parms = zi_lead_cat2 || zi_lead_cat3 || zi_lead_cat4 || zi_male || zi_black || zi_mexam || zi_o_race || zi_rural ||
					zi_reg_mw || zi_reg_s || zi_reg_w || zi_bel_pov || zi_less_hs || zi_more_hs || zi_smoke ||
					zi_low_bw || zi_high_bw || zi_breastf || zi_new_bd || zi_cond_vg_g || zi_cond_f_p;

	ext_cov_value = J(1,21,0);
	ext_cov_value = mean_lead2 || mean_lead3 || mean_lead4 || mean_male || mean_black || mean_mexam || mean_o_race || mean_rural ||
					mean_reg_mw || mean_reg_s || mean_reg_w || mean_bel_pov || mean_less_hs || mean_more_hs || mean_smoke ||
					mean_low_bw || mean_high_bw || mean_breastf || mean_new_bd || mean_cond_vg_g || mean_cond_f_p;

	ext_cov = ext_cov_parms * ext_cov_value`;

	g10_log_irr =  m_age_5 + log(1+exp(zi_int+ext_cov)) - log(1+exp(zi_int+ext_cov+zi_age_5));
	g10_theta = J(1,51,0);

	do i=1 to 25;
		g10_theta[1,i] = 0;
		if i=10 then g10_theta[1,i]=1;
	end;
	g10_theta[1,50] = (exp(zi_int+ext_cov))/((1+exp(zi_int+ext_cov)))-
					(exp(zi_int+ext_cov+zi_age_5)/(1+exp(zi_int+ext_cov+zi_age_5)));
	g10_theta[1,26] = mean_lead2		#g10_theta[1,50];
	g10_theta[1,27] = mean_lead3		#g10_theta[1,50];
	g10_theta[1,28] = mean_lead4		#g10_theta[1,50];
	g10_theta[1,29] = mean_male			#g10_theta[1,50];
	g10_theta[1,30] = mean_black		#g10_theta[1,50];
	g10_theta[1,31] = mean_mexam		#g10_theta[1,50];
	g10_theta[1,32] = mean_o_race		#g10_theta[1,50];
	g10_theta[1,33] = 0;
	g10_theta[1,34] = 0;
	g10_theta[1,35] = -(exp(zi_int+ext_cov+zi_age_5)/(1+exp(zi_int+ext_cov+zi_age_5)));
	g10_theta[1,36] = mean_rural		#g10_theta[1,50];
	g10_theta[1,37] = mean_reg_s		#g10_theta[1,50];
	g10_theta[1,38] = mean_reg_w		#g10_theta[1,50];
	g10_theta[1,39] = mean_reg_mw		#g10_theta[1,50];
	g10_theta[1,40] = mean_bel_pov		#g10_theta[1,50];
	g10_theta[1,41] = mean_less_hs		#g10_theta[1,50];
	g10_theta[1,42] = mean_more_hs		#g10_theta[1,50];
	g10_theta[1,43] = mean_smoke		#g10_theta[1,50];
	g10_theta[1,44] = mean_low_bw		#g10_theta[1,50];
	g10_theta[1,45] = mean_high_bw		#g10_theta[1,50];
	g10_theta[1,46] = mean_breastf		#g10_theta[1,50];
	g10_theta[1,47] = mean_new_bd		#g10_theta[1,50];
	g10_theta[1,48] = mean_cond_vg_g	#g10_theta[1,50];
	g10_theta[1,49] = mean_cond_f_p		#g10_theta[1,50];
	g10_theta[1,51] = 0;

	var_g10 = g10_theta * covar * g10_theta`; 
	se_g10  = sqrt(var_g10);

	g10_irr = exp(g10_log_irr);
	g10_irr_l = exp(g10_log_irr - 1.96*se_g10);
	g10_irr_u = exp(g10_log_irr + 1.96*se_g10);

* g11--Rural vs Urban;
	ext_cov_parms = J(1,23,0);
	ext_cov_parms = zi_lead_cat2 || zi_lead_cat3 || zi_lead_cat4 || zi_male || zi_black || zi_mexam || zi_o_race || zi_age_3 || zi_age_4 || zi_age_5 ||
					zi_reg_mw || zi_reg_s || zi_reg_w || zi_bel_pov || zi_less_hs || zi_more_hs || zi_smoke ||
					zi_low_bw || zi_high_bw || zi_breastf || zi_new_bd || zi_cond_vg_g || zi_cond_f_p;

	ext_cov_value = J(1,23,0);
	ext_cov_value = mean_lead2 || mean_lead3 || mean_lead4 || mean_male || mean_black || mean_mexam || mean_o_race || mean_age_3 || mean_age_4 || mean_age_5 ||
					mean_reg_mw || mean_reg_s || mean_reg_w || mean_bel_pov || mean_less_hs || mean_more_hs || mean_smoke ||
					mean_low_bw || mean_high_bw || mean_breastf || mean_new_bd || mean_cond_vg_g || mean_cond_f_p;

	ext_cov = ext_cov_parms * ext_cov_value`;

	g11_log_irr =  m_rural + log(1+exp(zi_int+ext_cov)) - log(1+exp(zi_int+ext_cov+zi_rural));
	g11_theta = J(1,51,0);

	do i=1 to 25;
		g11_theta[1,i] = 0;
		if i=11 then g11_theta[1,i]=1;
	end;
	g11_theta[1,50] = (exp(zi_int+ext_cov))/((1+exp(zi_int+ext_cov)))-
					(exp(zi_int+ext_cov+zi_rural)/(1+exp(zi_int+ext_cov+zi_rural)));
	g11_theta[1,26] = mean_lead2		#g11_theta[1,50];
	g11_theta[1,27] = mean_lead3		#g11_theta[1,50];
	g11_theta[1,28] = mean_lead4		#g11_theta[1,50];
	g11_theta[1,29] = mean_male			#g11_theta[1,50];
	g11_theta[1,30] = mean_black		#g11_theta[1,50];
	g11_theta[1,31] = mean_mexam		#g11_theta[1,50];
	g11_theta[1,32] = mean_o_race		#g11_theta[1,50];
	g11_theta[1,33] = mean_age_3		#g11_theta[1,50];
	g11_theta[1,34] = mean_age_4		#g11_theta[1,50];
	g11_theta[1,35] = mean_age_5		#g11_theta[1,50];
	g11_theta[1,36] = -(exp(zi_int+ext_cov+zi_rural)/(1+exp(zi_int+ext_cov+zi_rural)));
	g11_theta[1,37] = mean_reg_s		#g11_theta[1,50];
	g11_theta[1,38] = mean_reg_w		#g11_theta[1,50];
	g11_theta[1,39] = mean_reg_mw		#g11_theta[1,50];
	g11_theta[1,40] = mean_bel_pov		#g11_theta[1,50];
	g11_theta[1,41] = mean_less_hs		#g11_theta[1,50];
	g11_theta[1,42] = mean_more_hs		#g11_theta[1,50];
	g11_theta[1,43] = mean_smoke		#g11_theta[1,50];
	g11_theta[1,44] = mean_low_bw		#g11_theta[1,50];
	g11_theta[1,45] = mean_high_bw		#g11_theta[1,50];
	g11_theta[1,46] = mean_breastf		#g11_theta[1,50];
	g11_theta[1,47] = mean_new_bd		#g11_theta[1,50];
	g11_theta[1,48] = mean_cond_vg_g	#g11_theta[1,50];
	g11_theta[1,49] = mean_cond_f_p		#g11_theta[1,50];
	g11_theta[1,51] = 0;

	var_g11 = g11_theta * covar * g11_theta`; 
	se_g11  = sqrt(var_g11);

	g11_irr = exp(g11_log_irr);
	g11_irr_l = exp(g11_log_irr - 1.96*se_g11);
	g11_irr_u = exp(g11_log_irr + 1.96*se_g11);

* g12--Region: South vs NE;
	ext_cov_parms = J(1,21,0);
	ext_cov_parms = zi_lead_cat2 || zi_lead_cat3 || zi_lead_cat4 || zi_male || zi_black || zi_mexam || zi_o_race || zi_age_3 || zi_age_4 || zi_age_5 ||
					zi_rural || zi_bel_pov || zi_less_hs || zi_more_hs || zi_smoke ||
					zi_low_bw || zi_high_bw || zi_breastf || zi_new_bd || zi_cond_vg_g || zi_cond_f_p;

	ext_cov_value = J(1,21,0);
	ext_cov_value = mean_lead2 || mean_lead3 || mean_lead4 || mean_male || mean_black || mean_mexam || mean_o_race || mean_age_3 || mean_age_4 || mean_age_5 ||
					mean_rural || mean_bel_pov || mean_less_hs || mean_more_hs || mean_smoke ||
					mean_low_bw || mean_high_bw || mean_breastf || mean_new_bd || mean_cond_vg_g || mean_cond_f_p;

	ext_cov = ext_cov_parms * ext_cov_value`;

	g12_log_irr =  m_reg_s + log(1+exp(zi_int+ext_cov)) - log(1+exp(zi_int+ext_cov+zi_reg_s));
	g12_theta = J(1,51,0);

	do i=1 to 25;
		g12_theta[1,i] = 0;
		if i=12 then g12_theta[1,i]=1;
	end;
	g12_theta[1,50] = (exp(zi_int+ext_cov))/((1+exp(zi_int+ext_cov)))-
					(exp(zi_int+ext_cov+zi_reg_s)/(1+exp(zi_int+ext_cov+zi_reg_s)));
	g12_theta[1,26] = mean_lead2		#g12_theta[1,50];
	g12_theta[1,27] = mean_lead3		#g12_theta[1,50];
	g12_theta[1,28] = mean_lead4		#g12_theta[1,50];
	g12_theta[1,29] = mean_male			#g12_theta[1,50];
	g12_theta[1,30] = mean_black		#g12_theta[1,50];
	g12_theta[1,31] = mean_mexam		#g12_theta[1,50];
	g12_theta[1,32] = mean_o_race		#g12_theta[1,50];
	g12_theta[1,33] = mean_age_3		#g12_theta[1,50];
	g12_theta[1,34] = mean_age_4		#g12_theta[1,50];
	g12_theta[1,35] = mean_age_5		#g12_theta[1,50];
	g12_theta[1,36] = mean_rural		#g12_theta[1,50];
	g12_theta[1,37] = -(exp(zi_int+ext_cov+zi_reg_s)/(1+exp(zi_int+ext_cov+zi_reg_s)));
	g12_theta[1,38] = 0;
	g12_theta[1,39] = 0;
	g12_theta[1,40] = mean_bel_pov	#g12_theta[1,50];
	g12_theta[1,41] = mean_less_hs	#g12_theta[1,50];
	g12_theta[1,42] = mean_more_hs	#g12_theta[1,50];
	g12_theta[1,43] = mean_smoke		#g12_theta[1,50];
	g12_theta[1,44] = mean_low_bw	#g12_theta[1,50];
	g12_theta[1,45] = mean_high_bw	#g12_theta[1,50];
	g12_theta[1,46] = mean_breastf	#g12_theta[1,50];
	g12_theta[1,47] = mean_new_bd	#g12_theta[1,50];
	g12_theta[1,48] = mean_cond_vg_g	#g12_theta[1,50];
	g12_theta[1,49] = mean_cond_f_p	#g12_theta[1,50];
	g12_theta[1,51] = 0;

	var_g12 = g12_theta * covar * g12_theta`; 
	se_g12  = sqrt(var_g12);

	g12_irr = exp(g12_log_irr);
	g12_irr_l = exp(g12_log_irr - 1.96*se_g12);
	g12_irr_u = exp(g12_log_irr + 1.96*se_g12);

* g13--Region: West vs NE;
	ext_cov_parms = J(1,21,0);
	ext_cov_parms = zi_lead_cat2 || zi_lead_cat3 || zi_lead_cat4 || zi_male || zi_black || zi_mexam || zi_o_race || zi_age_3 || zi_age_4 || zi_age_5 ||
					zi_rural || zi_bel_pov || zi_less_hs || zi_more_hs || zi_smoke ||
					zi_low_bw || zi_high_bw || zi_breastf || zi_new_bd || zi_cond_vg_g || zi_cond_f_p;

	ext_cov_value = J(1,21,0);
	ext_cov_value = mean_lead2 || mean_lead3 || mean_lead4 || mean_male || mean_black || mean_mexam || mean_o_race || mean_age_3 || mean_age_4 || mean_age_5 ||
					mean_rural || mean_bel_pov || mean_less_hs || mean_more_hs || mean_smoke ||
					mean_low_bw || mean_high_bw || mean_breastf || mean_new_bd || mean_cond_vg_g || mean_cond_f_p;

	ext_cov = ext_cov_parms * ext_cov_value`;

	g13_log_irr =  m_reg_w + log(1+exp(zi_int+ext_cov)) - log(1+exp(zi_int+ext_cov+zi_reg_w));
	g13_theta = J(1,51,0);

	do i=1 to 25;
		g13_theta[1,i] = 0;
		if i=13 then g13_theta[1,i]=1;
	end;
	g13_theta[1,50] = (exp(zi_int+ext_cov))/((1+exp(zi_int+ext_cov)))-
					(exp(zi_int+ext_cov+zi_reg_w)/(1+exp(zi_int+ext_cov+zi_reg_w)));
	g13_theta[1,26] = mean_lead2		#g13_theta[1,50];
	g13_theta[1,27] = mean_lead3		#g13_theta[1,50];
	g13_theta[1,28] = mean_lead4		#g13_theta[1,50];
	g13_theta[1,29] = mean_male			#g13_theta[1,50];
	g13_theta[1,30] = mean_black		#g13_theta[1,50];
	g13_theta[1,31] = mean_mexam		#g13_theta[1,50];
	g13_theta[1,32] = mean_o_race		#g13_theta[1,50];
	g13_theta[1,33] = mean_age_3		#g13_theta[1,50];
	g13_theta[1,34] = mean_age_4		#g13_theta[1,50];
	g13_theta[1,35] = mean_age_5		#g13_theta[1,50];
	g13_theta[1,36] = mean_rural		#g13_theta[1,50];
	g13_theta[1,37] = 0;
	g13_theta[1,38] = -(exp(zi_int+ext_cov+zi_reg_w)/(1+exp(zi_int+ext_cov+zi_reg_w)));
	g13_theta[1,39] = 0;
	g13_theta[1,40] = mean_bel_pov		#g13_theta[1,50];
	g13_theta[1,41] = mean_less_hs		#g13_theta[1,50];
	g13_theta[1,42] = mean_more_hs		#g13_theta[1,50];
	g13_theta[1,43] = mean_smoke		#g13_theta[1,50];
	g13_theta[1,44] = mean_low_bw		#g13_theta[1,50];
	g13_theta[1,45] = mean_high_bw		#g13_theta[1,50];
	g13_theta[1,46] = mean_breastf		#g13_theta[1,50];
	g13_theta[1,47] = mean_new_bd		#g13_theta[1,50];
	g13_theta[1,48] = mean_cond_vg_g	#g13_theta[1,50];
	g13_theta[1,49] = mean_cond_f_p		#g13_theta[1,50];
	g13_theta[1,51] = 0;

	var_g13 = g13_theta * covar * g13_theta`; 
	se_g13  = sqrt(var_g13);

	g13_irr = exp(g13_log_irr);
	g13_irr_l = exp(g13_log_irr - 1.96*se_g13);
	g13_irr_u = exp(g13_log_irr + 1.96*se_g13);

* g14--Region: Midwest vs NE;
	ext_cov_parms = J(1,21,0);
	ext_cov_parms = zi_lead_cat2 || zi_lead_cat3 || zi_lead_cat4 || zi_male || zi_black || zi_mexam || zi_o_race || zi_age_3 || zi_age_4 || zi_age_5 ||
					zi_rural || zi_bel_pov || zi_less_hs || zi_more_hs || zi_smoke ||
					zi_low_bw || zi_high_bw || zi_breastf || zi_new_bd || zi_cond_vg_g || zi_cond_f_p;

	ext_cov_value = J(1,21,0);
	ext_cov_value = mean_lead2 || mean_lead3 || mean_lead4 || mean_male || mean_black || mean_mexam || mean_o_race || mean_age_3 || mean_age_4 || mean_age_5 ||
					mean_rural || mean_bel_pov || mean_less_hs || mean_more_hs || mean_smoke ||
					mean_low_bw || mean_high_bw || mean_breastf || mean_new_bd || mean_cond_vg_g || mean_cond_f_p;

	ext_cov = ext_cov_parms * ext_cov_value`;

	g14_log_irr =  m_reg_mw + log(1+exp(zi_int+ext_cov)) - log(1+exp(zi_int+ext_cov+zi_reg_mw));
	g14_theta = J(1,51,0);

	do i=1 to 25;
		g14_theta[1,i] = 0;
		if i=14 then g14_theta[1,i]=1;
	end;
	g14_theta[1,50] = (exp(zi_int+ext_cov))/((1+exp(zi_int+ext_cov)))-
					(exp(zi_int+ext_cov+zi_reg_mw)/(1+exp(zi_int+ext_cov+zi_reg_mw)));
	g14_theta[1,26] = mean_lead2		#g14_theta[1,50];
	g14_theta[1,27] = mean_lead3		#g14_theta[1,50];
	g14_theta[1,28] = mean_lead4		#g14_theta[1,50];
	g14_theta[1,29] = mean_male			#g14_theta[1,50];
	g14_theta[1,30] = mean_black		#g14_theta[1,50];
	g14_theta[1,31] = mean_mexam		#g14_theta[1,50];
	g14_theta[1,32] = mean_o_race		#g14_theta[1,50];
	g14_theta[1,33] = mean_age_3		#g14_theta[1,50];
	g14_theta[1,34] = mean_age_4		#g14_theta[1,50];
	g14_theta[1,35] = mean_age_5		#g14_theta[1,50];
	g14_theta[1,36] = mean_rural		#g14_theta[1,50];
	g14_theta[1,37] = 0;
	g14_theta[1,38] = 0;
	g14_theta[1,39] = -(exp(zi_int+ext_cov+zi_reg_mw)/(1+exp(zi_int+ext_cov+zi_reg_mw)));
	g14_theta[1,40] = mean_bel_pov		#g14_theta[1,50];
	g14_theta[1,41] = mean_less_hs		#g14_theta[1,50];
	g14_theta[1,42] = mean_more_hs		#g14_theta[1,50];
	g14_theta[1,43] = mean_smoke		#g14_theta[1,50];
	g14_theta[1,44] = mean_low_bw		#g14_theta[1,50];
	g14_theta[1,45] = mean_high_bw		#g14_theta[1,50];
	g14_theta[1,46] = mean_breastf		#g14_theta[1,50];
	g14_theta[1,47] = mean_new_bd		#g14_theta[1,50];
	g14_theta[1,48] = mean_cond_vg_g	#g14_theta[1,50];
	g14_theta[1,49] = mean_cond_f_p		#g14_theta[1,50];
	g14_theta[1,51] = 0;

	var_g14 = g14_theta * covar * g14_theta`; 
	se_g14  = sqrt(var_g14);

	g14_irr = exp(g14_log_irr);
	g14_irr_l = exp(g14_log_irr - 1.96*se_g14);
	g14_irr_u = exp(g14_log_irr + 1.96*se_g14);

* g15--Region: Below vs Above Poverty;
	ext_cov_parms = J(1,23,0);
	ext_cov_parms = zi_lead_cat2 || zi_lead_cat3 || zi_lead_cat4 || zi_male || zi_black || zi_mexam || zi_o_race || zi_age_3 || zi_age_4 || zi_age_5 ||
					zi_reg_s || zi_reg_w || zi_reg_mw || zi_less_hs || zi_more_hs || zi_smoke ||
					zi_low_bw || zi_high_bw || zi_breastf || zi_new_bd || zi_cond_vg_g || zi_cond_f_p;

	ext_cov_value = J(1,23,0);
	ext_cov_value = mean_lead2 || mean_lead3 || mean_lead4 || mean_male || mean_black || mean_mexam || mean_o_race || mean_age_3 || mean_age_4 || mean_age_5 ||
					mean_reg_s || mean_reg_w || mean_reg_mw || mean_less_hs || mean_more_hs || mean_smoke ||
					mean_low_bw || mean_high_bw || mean_breastf || mean_new_bd || mean_cond_vg_g || mean_cond_f_p;

	ext_cov = ext_cov_parms * ext_cov_value`;

	g15_log_irr =  m_bel_pov + log(1+exp(zi_int+ext_cov)) - log(1+exp(zi_int+ext_cov+zi_bel_pov));
	g15_theta = J(1,51,0);

	do i=1 to 25;
		g15_theta[1,i] = 0;
		if i=15 then g15_theta[1,i]=1;
	end;
	g15_theta[1,50] = (exp(zi_int+ext_cov))/((1+exp(zi_int+ext_cov)))-
					(exp(zi_int+ext_cov+zi_bel_pov)/(1+exp(zi_int+ext_cov+zi_bel_pov)));
	g15_theta[1,26] = mean_lead2		#g15_theta[1,50];
	g15_theta[1,27] = mean_lead3		#g15_theta[1,50];
	g15_theta[1,28] = mean_lead4		#g15_theta[1,50];
	g15_theta[1,29] = mean_male			#g15_theta[1,50];
	g15_theta[1,30] = mean_black		#g15_theta[1,50];
	g15_theta[1,31] = mean_mexam		#g15_theta[1,50];
	g15_theta[1,32] = mean_o_race		#g15_theta[1,50];
	g15_theta[1,33] = mean_age_3		#g15_theta[1,50];
	g15_theta[1,34] = mean_age_4		#g15_theta[1,50];
	g15_theta[1,35] = mean_age_5		#g15_theta[1,50];
	g15_theta[1,36] = mean_rural		#g15_theta[1,50];
	g15_theta[1,37] = mean_reg_s		#g15_theta[1,50];
	g15_theta[1,38] = mean_reg_w		#g15_theta[1,50];
	g15_theta[1,39] = mean_reg_mw		#g15_theta[1,50];
	g15_theta[1,40] = -(exp(zi_int+ext_cov+zi_bel_pov)/(1+exp(zi_int+ext_cov+zi_bel_pov)));
	g15_theta[1,41] = mean_less_hs		#g15_theta[1,50];
	g15_theta[1,42] = mean_more_hs		#g15_theta[1,50];
	g15_theta[1,43] = mean_smoke		#g15_theta[1,50];
	g15_theta[1,44] = mean_low_bw		#g15_theta[1,50];
	g15_theta[1,45] = mean_high_bw		#g15_theta[1,50];
	g15_theta[1,46] = mean_breastf		#g15_theta[1,50];
	g15_theta[1,47] = mean_new_bd		#g15_theta[1,50];
	g15_theta[1,48] = mean_cond_vg_g	#g15_theta[1,50];
	g15_theta[1,49] = mean_cond_f_p		#g15_theta[1,50];
	g15_theta[1,51] = 0;

	var_g15 = g15_theta * covar * g15_theta`; 
	se_g15  = sqrt(var_g15);

	g15_irr = exp(g15_log_irr);
	g15_irr_l = exp(g15_log_irr - 1.96*se_g15);
	g15_irr_u = exp(g15_log_irr + 1.96*se_g15);

* g16--Region: Less HS vs HS Education;
	ext_cov_parms = J(1,22,0);
	ext_cov_parms = zi_lead_cat2 || zi_lead_cat3 || zi_lead_cat4 || zi_male || zi_black || zi_mexam || zi_o_race || zi_age_3 || zi_age_4 || zi_age_5 ||
					zi_reg_s || zi_reg_w || zi_reg_mw || zi_bel_pov || zi_smoke ||
					zi_low_bw || zi_high_bw || zi_breastf || zi_new_bd || zi_cond_vg_g || zi_cond_f_p;

	ext_cov_value = J(1,22,0);
	ext_cov_value = mean_lead2 || mean_lead3 || mean_lead4 || mean_male || mean_black || mean_mexam || mean_o_race || mean_age_3 || mean_age_4 || mean_age_5 ||
					mean_reg_s || mean_reg_w || mean_reg_mw || mean_bel_pov || mean_smoke ||
					mean_low_bw || mean_high_bw || mean_breastf || mean_new_bd || mean_cond_vg_g || mean_cond_f_p;

	ext_cov = ext_cov_parms * ext_cov_value`;

	g16_log_irr =  m_less_hs + log(1+exp(zi_int+ext_cov)) - log(1+exp(zi_int+ext_cov+zi_less_hs));
	g16_theta = J(1,51,0);

	do i=1 to 25;
		g16_theta[1,i] = 0;
		if i=16 then g16_theta[1,i]=1;
	end;
	g16_theta[1,50] = (exp(zi_int+ext_cov))/((1+exp(zi_int+ext_cov)))-
					(exp(zi_int+ext_cov+zi_less_hs)/(1+exp(zi_int+ext_cov+zi_less_hs)));
	g16_theta[1,26] = mean_lead2		#g16_theta[1,50];
	g16_theta[1,27] = mean_lead3		#g16_theta[1,50];
	g16_theta[1,28] = mean_lead4		#g16_theta[1,50];
	g16_theta[1,29] = mean_male			#g16_theta[1,50];
	g16_theta[1,30] = mean_black		#g16_theta[1,50];
	g16_theta[1,31] = mean_mexam		#g16_theta[1,50];
	g16_theta[1,32] = mean_o_race		#g16_theta[1,50];
	g16_theta[1,33] = mean_age_3		#g16_theta[1,50];
	g16_theta[1,34] = mean_age_4		#g16_theta[1,50];
	g16_theta[1,35] = mean_age_5		#g16_theta[1,50];
	g16_theta[1,36] = mean_rural		#g16_theta[1,50];
	g16_theta[1,37] = mean_reg_s		#g16_theta[1,50];
	g16_theta[1,38] = mean_reg_w		#g16_theta[1,50];
	g16_theta[1,39] = mean_reg_mw		#g16_theta[1,50];
	g16_theta[1,40] = mean_bel_pov		#g16_theta[1,50];
	g16_theta[1,41] = -(exp(zi_int+ext_cov+zi_less_hs)/(1+exp(zi_int+ext_cov+zi_less_hs)));
	g16_theta[1,42] = 0;
	g16_theta[1,43] = mean_smoke		#g16_theta[1,50];
	g16_theta[1,44] = mean_low_bw		#g16_theta[1,50];
	g16_theta[1,45] = mean_high_bw		#g16_theta[1,50];
	g16_theta[1,46] = mean_breastf		#g16_theta[1,50];
	g16_theta[1,47] = mean_new_bd		#g16_theta[1,50];
	g16_theta[1,48] = mean_cond_vg_g	#g16_theta[1,50];
	g16_theta[1,49] = mean_cond_f_p		#g16_theta[1,50];
	g16_theta[1,51] = 0;

	var_g16 = g16_theta * covar * g16_theta`; 
	se_g16  = sqrt(var_g16);

	g16_irr = exp(g16_log_irr);
	g16_irr_l = exp(g16_log_irr - 1.96*se_g16);
	g16_irr_u = exp(g16_log_irr + 1.96*se_g16);

* g17--Region: More HS vs HS Education;
	ext_cov_parms = J(1,22,0);
	ext_cov_parms = zi_lead_cat2 || zi_lead_cat3 || zi_lead_cat4 || zi_male || zi_black || zi_mexam || zi_o_race || zi_age_3 || zi_age_4 || zi_age_5 ||
					zi_reg_s || zi_reg_w || zi_reg_mw || zi_bel_pov || zi_smoke ||
					zi_low_bw || zi_high_bw || zi_breastf || zi_new_bd || zi_cond_vg_g || zi_cond_f_p;

	ext_cov_value = J(1,22,0);
	ext_cov_value = mean_lead2 || mean_lead3 || mean_lead4 || mean_male || mean_black || mean_mexam || mean_o_race || mean_age_3 || mean_age_4 || mean_age_5 ||
					mean_reg_s || mean_reg_w || mean_reg_mw || mean_bel_pov || mean_smoke ||
					mean_low_bw || mean_high_bw || mean_breastf || mean_new_bd || mean_cond_vg_g || mean_cond_f_p;

	ext_cov = ext_cov_parms * ext_cov_value`;

	g17_log_irr =  m_more_hs + log(1+exp(zi_int+ext_cov)) - log(1+exp(zi_int+ext_cov+zi_more_hs));
	g17_theta = J(1,51,0);

	do i=1 to 25;
		g17_theta[1,i] = 0;
		if i=17 then g17_theta[1,i]=1;
	end;
	g17_theta[1,50] = (exp(zi_int+ext_cov))/((1+exp(zi_int+ext_cov)))-
					(exp(zi_int+ext_cov+zi_more_hs)/(1+exp(zi_int+ext_cov+zi_more_hs)));
	g17_theta[1,26] = mean_lead2		#g17_theta[1,50];
	g17_theta[1,27] = mean_lead3		#g17_theta[1,50];
	g17_theta[1,28] = mean_lead4		#g17_theta[1,50];
	g17_theta[1,29] = mean_male			#g17_theta[1,50];
	g17_theta[1,30] = mean_black		#g17_theta[1,50];
	g17_theta[1,31] = mean_mexam		#g17_theta[1,50];
	g17_theta[1,32] = mean_o_race		#g17_theta[1,50];
	g17_theta[1,33] = mean_age_3		#g17_theta[1,50];
	g17_theta[1,34] = mean_age_4		#g17_theta[1,50];
	g17_theta[1,35] = mean_age_5		#g17_theta[1,50];
	g17_theta[1,36] = mean_rural		#g17_theta[1,50];
	g17_theta[1,37] = mean_reg_s		#g17_theta[1,50];
	g17_theta[1,38] = mean_reg_w		#g17_theta[1,50];
	g17_theta[1,39] = mean_reg_mw		#g17_theta[1,50];
	g17_theta[1,40] = mean_bel_pov		#g17_theta[1,50];
	g17_theta[1,41] = 0;
	g17_theta[1,42] = -(exp(zi_int+ext_cov+zi_more_hs)/(1+exp(zi_int+ext_cov+zi_more_hs)));
	g17_theta[1,43] = mean_smoke		#g17_theta[1,50];
	g17_theta[1,44] = mean_low_bw		#g17_theta[1,50];
	g17_theta[1,45] = mean_high_bw		#g17_theta[1,50];
	g17_theta[1,46] = mean_breastf		#g17_theta[1,50];
	g17_theta[1,47] = mean_new_bd		#g17_theta[1,50];
	g17_theta[1,48] = mean_cond_vg_g	#g17_theta[1,50];
	g17_theta[1,49] = mean_cond_f_p		#g17_theta[1,50];
	g17_theta[1,51] = 0;

	var_g17 = g17_theta * covar * g17_theta`; 
	se_g17  = sqrt(var_g17);

	g17_irr = exp(g17_log_irr);
	g17_irr_l = exp(g17_log_irr - 1.96*se_g17);
	g17_irr_u = exp(g17_log_irr + 1.96*se_g17);

* g18--Region: Smoke vs Non Smoke HH;
	ext_cov_parms = J(1,23,0);
	ext_cov_parms = zi_lead_cat2 || zi_lead_cat3 || zi_lead_cat4 || zi_male || zi_black || zi_mexam || zi_o_race || zi_age_3 || zi_age_4 || zi_age_5 ||
					zi_reg_s || zi_reg_w || zi_reg_mw || zi_bel_pov || zi_less_hs || zi_more_hs || 
					zi_low_bw || zi_high_bw || zi_breastf || zi_new_bd || zi_cond_vg_g || zi_cond_f_p;

	ext_cov_value = J(1,23,0);
	ext_cov_value = mean_lead2 || mean_lead3 || mean_lead4 || mean_male || mean_black || mean_mexam || mean_o_race || mean_age_3 || mean_age_4 || mean_age_5 ||
					mean_reg_s || mean_reg_w || mean_reg_mw || mean_bel_pov || mean_less_hs || mean_more_hs ||
					mean_low_bw || mean_high_bw || mean_breastf || mean_new_bd || mean_cond_vg_g || mean_cond_f_p;

	ext_cov = ext_cov_parms * ext_cov_value`;

	g18_log_irr =  m_smoke + log(1+exp(zi_int+ext_cov)) - log(1+exp(zi_int+ext_cov+zi_smoke));
	g18_theta = J(1,51,0);

	do i=1 to 25;
		g18_theta[1,i] = 0;
		if i=18 then g18_theta[1,i]=1;
	end;
	g18_theta[1,50] = (exp(zi_int+ext_cov))/((1+exp(zi_int+ext_cov)))-
					(exp(zi_int+ext_cov+zi_smoke)/(1+exp(zi_int+ext_cov+zi_smoke)));
	g18_theta[1,26] = mean_lead2		#g18_theta[1,50];
	g18_theta[1,27] = mean_lead3		#g18_theta[1,50];
	g18_theta[1,28] = mean_lead4		#g18_theta[1,50];
	g18_theta[1,29] = mean_male			#g18_theta[1,50];
	g18_theta[1,30] = mean_black		#g18_theta[1,50];
	g18_theta[1,31] = mean_mexam		#g18_theta[1,50];
	g18_theta[1,32] = mean_o_race		#g18_theta[1,50];
	g18_theta[1,33] = mean_age_3		#g18_theta[1,50];
	g18_theta[1,34] = mean_age_4		#g18_theta[1,50];
	g18_theta[1,35] = mean_age_5		#g18_theta[1,50];
	g18_theta[1,36] = mean_rural		#g18_theta[1,50];
	g18_theta[1,37] = mean_reg_s		#g18_theta[1,50];
	g18_theta[1,38] = mean_reg_w		#g18_theta[1,50];
	g18_theta[1,39] = mean_reg_mw		#g18_theta[1,50];
	g18_theta[1,40] = mean_bel_pov		#g18_theta[1,50];
	g18_theta[1,41] = mean_less_hs		#g18_theta[1,50];
	g18_theta[1,42] = mean_more_hs		#g18_theta[1,50];
	g18_theta[1,43] = -(exp(zi_int+ext_cov+zi_smoke)/(1+exp(zi_int+ext_cov+zi_smoke)));
	g18_theta[1,44] = mean_low_bw		#g18_theta[1,50];
	g18_theta[1,45] = mean_high_bw		#g18_theta[1,50];
	g18_theta[1,46] = mean_breastf		#g18_theta[1,50];
	g18_theta[1,47] = mean_new_bd		#g18_theta[1,50];
	g18_theta[1,48] = mean_cond_vg_g	#g18_theta[1,50];
	g18_theta[1,49] = mean_cond_f_p		#g18_theta[1,50];
	g18_theta[1,51] = 0;

	var_g18 = g18_theta * covar * g18_theta`; 
	se_g18  = sqrt(var_g18);

	g18_irr = exp(g18_log_irr);
	g18_irr_l = exp(g18_log_irr - 1.96*se_g18);
	g18_irr_u = exp(g18_log_irr + 1.96*se_g18);

* g19--BW: Low vs Normal;
	ext_cov_parms = J(1,22,0);
	ext_cov_parms = zi_lead_cat2 || zi_lead_cat3 || zi_lead_cat4 || zi_male || zi_black || zi_mexam || zi_o_race || zi_age_3 || zi_age_4 || zi_age_5 ||
					zi_reg_s || zi_reg_w || zi_reg_mw || zi_bel_pov || zi_less_hs || zi_more_hs || zi_smoke
					|| zi_breastf || zi_new_bd || zi_cond_vg_g || zi_cond_f_p;

	ext_cov_value = J(1,22,0);
	ext_cov_value = mean_lead2 || mean_lead3 || mean_lead4 || mean_male || mean_black || mean_mexam || mean_o_race || mean_age_3 || mean_age_4 || mean_age_5 ||
					mean_reg_s || mean_reg_w || mean_reg_mw || mean_bel_pov || mean_less_hs || mean_more_hs || mean_smoke
					|| mean_breastf || mean_new_bd || mean_cond_vg_g || mean_cond_f_p;

	ext_cov = ext_cov_parms * ext_cov_value`;

	g19_log_irr =  m_low_bw + log(1+exp(zi_int+ext_cov)) - log(1+exp(zi_int+ext_cov+zi_low_bw));
	g19_theta = J(1,51,0);

	do i=1 to 25;
		g19_theta[1,i] = 0;
		if i=19 then g19_theta[1,i]=1;
	end;
	g19_theta[1,50] = (exp(zi_int+ext_cov))/((1+exp(zi_int+ext_cov)))-
					(exp(zi_int+ext_cov+zi_low_bw)/(1+exp(zi_int+ext_cov+zi_low_bw)));
	g19_theta[1,26] = mean_lead2		#g19_theta[1,50];
	g19_theta[1,27] = mean_lead3		#g19_theta[1,50];
	g19_theta[1,28] = mean_lead4		#g19_theta[1,50];
	g19_theta[1,29] = mean_male			#g19_theta[1,50];
	g19_theta[1,30] = mean_black		#g19_theta[1,50];
	g19_theta[1,31] = mean_mexam		#g19_theta[1,50];
	g19_theta[1,32] = mean_o_race		#g19_theta[1,50];
	g19_theta[1,33] = mean_age_3		#g19_theta[1,50];
	g19_theta[1,34] = mean_age_4		#g19_theta[1,50];
	g19_theta[1,35] = mean_age_5		#g19_theta[1,50];
	g19_theta[1,36] = mean_rural		#g19_theta[1,50];
	g19_theta[1,37] = mean_reg_s		#g19_theta[1,50];
	g19_theta[1,38] = mean_reg_w		#g19_theta[1,50];
	g19_theta[1,39] = mean_reg_mw		#g19_theta[1,50];
	g19_theta[1,40] = mean_bel_pov		#g19_theta[1,50];
	g19_theta[1,41] = mean_less_hs		#g19_theta[1,50];
	g19_theta[1,42] = mean_more_hs		#g19_theta[1,50];
	g19_theta[1,43] = mean_smoke		#g19_theta[1,50];
	g19_theta[1,44] = -(exp(zi_int+ext_cov+zi_low_bw)/(1+exp(zi_int+ext_cov+zi_low_bw)));
	g19_theta[1,45] = 0;
	g19_theta[1,46] = mean_breastf		#g19_theta[1,50];
	g19_theta[1,47] = mean_new_bd		#g19_theta[1,50];
	g19_theta[1,48] = mean_cond_vg_g	#g19_theta[1,50];
	g19_theta[1,49] = mean_cond_f_p		#g19_theta[1,50];
	g19_theta[1,51] = 0;

	var_g19 = g19_theta * covar * g19_theta`; 
	se_g19  = sqrt(var_g19);

	g19_irr = exp(g19_log_irr);
	g19_irr_l = exp(g19_log_irr - 1.96*se_g19);
	g19_irr_u = exp(g19_log_irr + 1.96*se_g19);

* g20--BW: High vs Normal;
	ext_cov_parms = J(1,22,0);
	ext_cov_parms = zi_lead_cat2 || zi_lead_cat3 || zi_lead_cat4 || zi_male || zi_black || zi_mexam || zi_o_race || zi_age_3 || zi_age_4 || zi_age_5 ||
					zi_reg_s || zi_reg_w || zi_reg_mw || zi_bel_pov || zi_less_hs || zi_more_hs || zi_smoke
					|| zi_breastf || zi_new_bd || zi_cond_vg_g || zi_cond_f_p;

	ext_cov_value = J(1,22,0);
	ext_cov_value = mean_lead2 || mean_lead3 || mean_lead4 || mean_male || mean_black || mean_mexam || mean_o_race || mean_age_3 || mean_age_4 || mean_age_5 ||
					mean_reg_s || mean_reg_w || mean_reg_mw || mean_bel_pov || mean_less_hs || mean_more_hs || mean_smoke
					|| mean_breastf || mean_new_bd || mean_cond_vg_g || mean_cond_f_p;

	ext_cov = ext_cov_parms * ext_cov_value`;

	g20_log_irr =  m_high_bw + log(1+exp(zi_int+ext_cov)) - log(1+exp(zi_int+ext_cov+zi_high_bw));
	g20_theta = J(1,51,0);

	do i=1 to 25;
		g20_theta[1,i] = 0;
		if i=20 then g20_theta[1,i]=1;
	end;
	g20_theta[1,50] = (exp(zi_int+ext_cov))/((1+exp(zi_int+ext_cov)))-
					(exp(zi_int+ext_cov+zi_high_bw)/(1+exp(zi_int+ext_cov+zi_high_bw)));
	g20_theta[1,26] = mean_lead2		#g20_theta[1,50];
	g20_theta[1,27] = mean_lead3		#g20_theta[1,50];
	g20_theta[1,28] = mean_lead4		#g20_theta[1,50];
	g20_theta[1,29] = mean_male			#g20_theta[1,50];
	g20_theta[1,30] = mean_black		#g20_theta[1,50];
	g20_theta[1,31] = mean_mexam		#g20_theta[1,50];
	g20_theta[1,32] = mean_o_race		#g20_theta[1,50];
	g20_theta[1,33] = mean_age_3		#g20_theta[1,50];
	g20_theta[1,34] = mean_age_4		#g20_theta[1,50];
	g20_theta[1,35] = mean_age_5		#g20_theta[1,50];
	g20_theta[1,36] = mean_rural		#g20_theta[1,50];
	g20_theta[1,37] = mean_reg_s		#g20_theta[1,50];
	g20_theta[1,38] = mean_reg_w		#g20_theta[1,50];
	g20_theta[1,39] = mean_reg_mw		#g20_theta[1,50];
	g20_theta[1,40] = mean_bel_pov		#g20_theta[1,50];
	g20_theta[1,41] = mean_less_hs		#g20_theta[1,50];
	g20_theta[1,42] = mean_more_hs		#g20_theta[1,50];
	g20_theta[1,43] = mean_smoke		#g20_theta[1,50];
	g20_theta[1,44] = 0;
	g20_theta[1,45] = -(exp(zi_int+ext_cov+zi_high_bw)/(1+exp(zi_int+ext_cov+zi_high_bw)));
	g20_theta[1,46] = mean_breastf		#g20_theta[1,50];
	g20_theta[1,47] = mean_new_bd		#g20_theta[1,50];
	g20_theta[1,48] = mean_cond_vg_g	#g20_theta[1,50];
	g20_theta[1,49] = mean_cond_f_p		#g20_theta[1,50];
	g20_theta[1,51] = 0;

	var_g20 = g20_theta * covar * g20_theta`; 
	se_g20  = sqrt(var_g20);

	g20_irr = exp(g20_log_irr);
	g20_irr_l = exp(g20_log_irr - 1.96*se_g20);
	g20_irr_u = exp(g20_log_irr + 1.96*se_g20);

* g21--BF: Yes vs No;
	ext_cov_parms = J(1,23,0);
	ext_cov_parms = zi_lead_cat2 || zi_lead_cat3 || zi_lead_cat4 || zi_male || zi_black || zi_mexam || zi_o_race || zi_age_3 || zi_age_4 || zi_age_5 ||
					zi_reg_s || zi_reg_w || zi_reg_mw || zi_bel_pov || zi_less_hs || zi_more_hs || zi_smoke ||
					zi_low_bw || zi_high_bw || zi_new_bd || zi_cond_vg_g || zi_cond_f_p;

	ext_cov_value = J(1,23,0);
	ext_cov_value = mean_lead2 || mean_lead3 || mean_lead4 || mean_male || mean_black || mean_mexam || mean_o_race || mean_age_3 || mean_age_4 || mean_age_5 ||
					mean_reg_s || mean_reg_w || mean_reg_mw || mean_bel_pov || mean_less_hs || mean_more_hs || mean_smoke ||
					mean_low_bw || mean_high_bw || mean_new_bd || mean_cond_vg_g || mean_cond_f_p;

	ext_cov = ext_cov_parms * ext_cov_value`;

	g21_log_irr =  m_breastf + log(1+exp(zi_int+ext_cov)) - log(1+exp(zi_int+ext_cov+zi_breastf));
	g21_theta = J(1,51,0);

	do i=1 to 25;
		g21_theta[1,i] = 0;
		if i=21 then g21_theta[1,i]=1;
	end;
	g21_theta[1,50] = (exp(zi_int+ext_cov))/((1+exp(zi_int+ext_cov)))-
					(exp(zi_int+ext_cov+zi_breastf)/(1+exp(zi_int+ext_cov+zi_breastf)));
	g21_theta[1,26] = mean_lead2		#g21_theta[1,50];
	g21_theta[1,27] = mean_lead3		#g21_theta[1,50];
	g21_theta[1,28] = mean_lead4		#g21_theta[1,50];
	g21_theta[1,29] = mean_male			#g21_theta[1,50];
	g21_theta[1,30] = mean_black		#g21_theta[1,50];
	g21_theta[1,31] = mean_mexam		#g21_theta[1,50];
	g21_theta[1,32] = mean_o_race		#g21_theta[1,50];
	g21_theta[1,33] = mean_age_3		#g21_theta[1,50];
	g21_theta[1,34] = mean_age_4		#g21_theta[1,50];
	g21_theta[1,35] = mean_age_5		#g21_theta[1,50];
	g21_theta[1,36] = mean_rural		#g21_theta[1,50];
	g21_theta[1,37] = mean_reg_s		#g21_theta[1,50];
	g21_theta[1,38] = mean_reg_w		#g21_theta[1,50];
	g21_theta[1,39] = mean_reg_mw		#g21_theta[1,50];
	g21_theta[1,40] = mean_bel_pov		#g21_theta[1,50];
	g21_theta[1,41] = mean_less_hs		#g21_theta[1,50];
	g21_theta[1,42] = mean_more_hs		#g21_theta[1,50];
	g21_theta[1,43] = mean_smoke		#g21_theta[1,50];
	g21_theta[1,44] = mean_low_bw		#g21_theta[1,50];
	g21_theta[1,45] = mean_high_bw		#g21_theta[1,50];
	g21_theta[1,46] = -(exp(zi_int+ext_cov+zi_breastf)/(1+exp(zi_int+ext_cov+zi_breastf)));
	g21_theta[1,47] = mean_new_bd		#g21_theta[1,50];
	g21_theta[1,48] = mean_cond_vg_g	#g21_theta[1,50];
	g21_theta[1,49] = mean_cond_f_p		#g21_theta[1,50];
	g21_theta[1,51] = 0;

	var_g21 = g21_theta * covar * g21_theta`; 
	se_g21  = sqrt(var_g21);

	g21_irr = exp(g21_log_irr);
	g21_irr_l = exp(g21_log_irr - 1.96*se_g21);
	g21_irr_u = exp(g21_log_irr + 1.96*se_g21);

* g22--Been Dentist: Yes vs No;
	ext_cov_parms = J(1,23,0);
	ext_cov_parms = zi_lead_cat2 || zi_lead_cat3 || zi_lead_cat4 || zi_male || zi_black || zi_mexam || zi_o_race || zi_age_3 || zi_age_4 || zi_age_5 ||
					zi_reg_s || zi_reg_w || zi_reg_mw || zi_bel_pov || zi_less_hs || zi_more_hs || zi_smoke ||
					zi_low_bw || zi_high_bw || zi_breastf || zi_cond_vg_g || zi_cond_f_p;

	ext_cov_value = J(1,23,0);
	ext_cov_value = mean_lead2 || mean_lead3 || mean_lead4 || mean_male || mean_black || mean_mexam || mean_o_race || mean_age_3 || mean_age_4 || mean_age_5 ||
					mean_reg_s || mean_reg_w || mean_reg_mw || mean_bel_pov || mean_less_hs || mean_more_hs || mean_smoke ||
					mean_low_bw || mean_high_bw || mean_breastf || mean_cond_vg_g || mean_cond_f_p;

	ext_cov = ext_cov_parms * ext_cov_value`;

	g22_log_irr =  m_new_bd + log(1+exp(zi_int+ext_cov)) - log(1+exp(zi_int+ext_cov+zi_new_bd));
	g22_theta = J(1,51,0);

	do i=1 to 25;
		g22_theta[1,i] = 0;
		if i=22 then g22_theta[1,i]=1;
	end;
	g22_theta[1,50] = (exp(zi_int+ext_cov))/((1+exp(zi_int+ext_cov)))-
					(exp(zi_int+ext_cov+zi_new_bd)/(1+exp(zi_int+ext_cov+zi_new_bd)));
	g22_theta[1,26] = mean_lead2		#g22_theta[1,50];
	g22_theta[1,27] = mean_lead3		#g22_theta[1,50];
	g22_theta[1,28] = mean_lead4		#g22_theta[1,50];
	g22_theta[1,29] = mean_male			#g22_theta[1,50];
	g22_theta[1,30] = mean_black		#g22_theta[1,50];
	g22_theta[1,31] = mean_mexam		#g22_theta[1,50];
	g22_theta[1,32] = mean_o_race		#g22_theta[1,50];
	g22_theta[1,33] = mean_age_3		#g22_theta[1,50];
	g22_theta[1,34] = mean_age_4		#g22_theta[1,50];
	g22_theta[1,35] = mean_age_5		#g22_theta[1,50];
	g22_theta[1,36] = mean_rural		#g22_theta[1,50];
	g22_theta[1,37] = mean_reg_s		#g22_theta[1,50];
	g22_theta[1,38] = mean_reg_w		#g22_theta[1,50];
	g22_theta[1,39] = mean_reg_mw		#g22_theta[1,50];
	g22_theta[1,40] = mean_bel_pov		#g22_theta[1,50];
	g22_theta[1,41] = mean_less_hs		#g22_theta[1,50];
	g22_theta[1,42] = mean_more_hs		#g22_theta[1,50];
	g22_theta[1,43] = mean_smoke		#g22_theta[1,50];
	g22_theta[1,44] = mean_low_bw		#g22_theta[1,50];
	g22_theta[1,45] = mean_high_bw		#g22_theta[1,50];
	g22_theta[1,46] = mean_breastf		#g22_theta[1,50];
	g22_theta[1,47] = -(exp(zi_int+ext_cov+zi_new_bd)/(1+exp(zi_int+ext_cov+zi_new_bd)));
	g22_theta[1,48] = mean_cond_vg_g	#g22_theta[1,50];
	g22_theta[1,49] = mean_cond_f_p		#g22_theta[1,50];
	g22_theta[1,51] = 0;

	var_g22 = g22_theta * covar * g22_theta`; 
	se_g22  = sqrt(var_g22);

	g22_irr = exp(g22_log_irr);
	g22_irr_l = exp(g22_log_irr - 1.96*se_g22);
	g22_irr_u = exp(g22_log_irr + 1.96*se_g22);

* g23--Condition: VG/G vs Exc;
	ext_cov_parms = J(1,22,0);
	ext_cov_parms = zi_lead_cat2 || zi_lead_cat3 || zi_lead_cat4 || zi_male || zi_black || zi_mexam || zi_o_race || zi_age_3 || zi_age_4 || zi_age_5 ||
					zi_reg_s || zi_reg_w || zi_reg_mw || zi_bel_pov || zi_less_hs || zi_more_hs || zi_smoke ||
					zi_low_bw || zi_high_bw || zi_breastf || zi_new_bd;

	ext_cov_value = J(1,22,0);
	ext_cov_value = mean_lead2 || mean_lead3 || mean_lead4 || mean_male || mean_black || mean_mexam || mean_o_race || mean_age_3 || mean_age_4 || mean_age_5 ||
					mean_reg_s || mean_reg_w || mean_reg_mw || mean_bel_pov || mean_less_hs || mean_more_hs || mean_smoke ||
					mean_low_bw || mean_high_bw || mean_breastf || mean_new_bd;

	ext_cov = ext_cov_parms * ext_cov_value`;

	g23_log_irr =  m_cond_vg_g + log(1+exp(zi_int+ext_cov)) - log(1+exp(zi_int+ext_cov+zi_cond_vg_g));
	g23_theta = J(1,51,0);

	do i=1 to 25;
		g23_theta[1,i] = 0;
		if i=23 then g23_theta[1,i]=1;
	end;
	g23_theta[1,50] = (exp(zi_int+ext_cov))/((1+exp(zi_int+ext_cov)))-
					(exp(zi_int+ext_cov+zi_cond_vg_g)/(1+exp(zi_int+ext_cov+zi_cond_vg_g)));
	g23_theta[1,26] = mean_lead2		#g23_theta[1,50];
	g23_theta[1,27] = mean_lead3		#g23_theta[1,50];
	g23_theta[1,28] = mean_lead4		#g23_theta[1,50];
	g23_theta[1,29] = mean_male			#g23_theta[1,50];
	g23_theta[1,30] = mean_black		#g23_theta[1,50];
	g23_theta[1,31] = mean_mexam		#g23_theta[1,50];
	g23_theta[1,32] = mean_o_race		#g23_theta[1,50];
	g23_theta[1,33] = mean_age_3		#g23_theta[1,50];
	g23_theta[1,34] = mean_age_4		#g23_theta[1,50];
	g23_theta[1,35] = mean_age_5		#g23_theta[1,50];
	g23_theta[1,36] = mean_rural		#g23_theta[1,50];
	g23_theta[1,37] = mean_reg_s		#g23_theta[1,50];
	g23_theta[1,38] = mean_reg_w		#g23_theta[1,50];
	g23_theta[1,39] = mean_reg_mw		#g23_theta[1,50];
	g23_theta[1,40] = mean_bel_pov		#g23_theta[1,50];
	g23_theta[1,41] = mean_less_hs		#g23_theta[1,50];
	g23_theta[1,42] = mean_more_hs		#g23_theta[1,50];
	g23_theta[1,43] = mean_smoke		#g23_theta[1,50];
	g23_theta[1,44] = mean_low_bw		#g23_theta[1,50];
	g23_theta[1,45] = mean_high_bw		#g23_theta[1,50];
	g23_theta[1,46] = mean_breastf		#g23_theta[1,50];
	g23_theta[1,47] = mean_new_bd		#g23_theta[1,50];
	g23_theta[1,48] = -(exp(zi_int+ext_cov+zi_cond_vg_g)/(1+exp(zi_int+ext_cov+zi_cond_vg_g)));
	g23_theta[1,49] = 0;
	g23_theta[1,51] = 0;

	var_g23 = g23_theta * covar * g23_theta`; 
	se_g23  = sqrt(var_g23);

	g23_irr = exp(g23_log_irr);
	g23_irr_l = exp(g23_log_irr - 1.96*se_g23);
	g23_irr_u = exp(g23_log_irr + 1.96*se_g23);

* g24--Condition: F/P vs Exc;
	ext_cov_parms = J(1,22,0);
	ext_cov_parms = zi_lead_cat2 || zi_lead_cat3 || zi_lead_cat4 || zi_male || zi_black || zi_mexam || zi_o_race || zi_age_3 || zi_age_4 || zi_age_5 ||
					zi_reg_s || zi_reg_w || zi_reg_mw || zi_bel_pov || zi_less_hs || zi_more_hs || zi_smoke ||
					zi_low_bw || zi_high_bw || zi_breastf || zi_new_bd;

	ext_cov_value = J(1,22,0);
	ext_cov_value = mean_lead2 || mean_lead3 || mean_lead4 || mean_male || mean_black || mean_mexam || mean_o_race || mean_age_3 || mean_age_4 || mean_age_5 ||
					mean_reg_s || mean_reg_w || mean_reg_mw || mean_bel_pov || mean_less_hs || mean_more_hs || mean_smoke ||
					mean_low_bw || mean_high_bw || mean_breastf || mean_new_bd;

	ext_cov = ext_cov_parms * ext_cov_value`;

	g24_log_irr =  m_cond_f_p + log(1+exp(zi_int+ext_cov)) - log(1+exp(zi_int+ext_cov+zi_cond_f_p));
	g24_theta = J(1,51,0);

	do i=1 to 25;
		g24_theta[1,i] = 0;
		if i=24 then g24_theta[1,i]=1;
	end;
	g24_theta[1,50] = (exp(zi_int+ext_cov))/((1+exp(zi_int+ext_cov)))-
					(exp(zi_int+ext_cov+zi_cond_f_p)/(1+exp(zi_int+ext_cov+zi_cond_f_p)));
	g24_theta[1,26] = mean_lead2		#g24_theta[1,50];
	g24_theta[1,27] = mean_lead3		#g24_theta[1,50];
	g24_theta[1,28] = mean_lead4		#g24_theta[1,50];
	g24_theta[1,29] = mean_male			#g24_theta[1,50];
	g24_theta[1,30] = mean_black		#g24_theta[1,50];
	g24_theta[1,31] = mean_mexam		#g24_theta[1,50];
	g24_theta[1,32] = mean_o_race		#g24_theta[1,50];
	g24_theta[1,33] = mean_age_3		#g24_theta[1,50];
	g24_theta[1,34] = mean_age_4		#g24_theta[1,50];
	g24_theta[1,35] = mean_age_5		#g24_theta[1,50];
	g24_theta[1,36] = mean_rural		#g24_theta[1,50];
	g24_theta[1,37] = mean_reg_s		#g24_theta[1,50];
	g24_theta[1,38] = mean_reg_w		#g24_theta[1,50];
	g24_theta[1,39] = mean_reg_mw		#g24_theta[1,50];
	g24_theta[1,40] = mean_bel_pov		#g24_theta[1,50];
	g24_theta[1,41] = mean_less_hs		#g24_theta[1,50];
	g24_theta[1,42] = mean_more_hs		#g24_theta[1,50];
	g24_theta[1,43] = mean_smoke		#g24_theta[1,50];
	g24_theta[1,44] = mean_low_bw		#g24_theta[1,50];
	g24_theta[1,45] = mean_high_bw		#g24_theta[1,50];
	g24_theta[1,46] = mean_breastf		#g24_theta[1,50];
	g24_theta[1,47] = mean_new_bd		#g24_theta[1,50];
	g24_theta[1,48] = 0;
	g24_theta[1,49] = -(exp(zi_int+ext_cov+zi_cond_f_p)/(1+exp(zi_int+ext_cov+zi_cond_f_p)));
	g24_theta[1,51] = 0;

	var_g24 = g24_theta * covar * g24_theta`; 
	se_g24  = sqrt(var_g24);

	g24_irr = exp(g24_log_irr);
	g24_irr_l = exp(g24_log_irr - 1.96*se_g24);
	g24_irr_u = exp(g24_log_irr + 1.96*se_g24);


	**** OUTPUT ****;
	blah1 = g1_log_irr || var_g1 || se_g1 || g1_irr || g1_irr_l || g1_irr_u;
	blah2 = g2_log_irr || var_g2 || se_g2 || g2_irr || g2_irr_l || g2_irr_u;
	blah3 = g3_log_irr || var_g3 || se_g3 || g3_irr || g3_irr_l || g3_irr_u;
	blah4 = g4_log_irr || var_g4 || se_g4 || g4_irr || g4_irr_l || g4_irr_u;
	blah5 = g5_log_irr || var_g5 || se_g5 || g5_irr || g5_irr_l || g5_irr_u;
	blah6 = g6_log_irr || var_g6 || se_g6 || g6_irr || g6_irr_l || g6_irr_u;
	blah7 = g7_log_irr || var_g7 || se_g7 || g7_irr || g7_irr_l || g7_irr_u;
	blah8 = g8_log_irr || var_g8 || se_g8 || g8_irr || g8_irr_l || g8_irr_u;
	blah9 = g9_log_irr || var_g9 || se_g9 || g9_irr || g9_irr_l || g9_irr_u;
	blah10 = g10_log_irr || var_g10 || se_g10 || g10_irr || g10_irr_l || g10_irr_u;
	blah11 = g11_log_irr || var_g11 || se_g11 || g11_irr || g11_irr_l || g11_irr_u;
	blah12 = g12_log_irr || var_g12 || se_g12 || g12_irr || g12_irr_l || g12_irr_u;
	blah13 = g13_log_irr || var_g13 || se_g13 || g13_irr || g13_irr_l || g13_irr_u;
	blah14 = g14_log_irr || var_g14 || se_g14 || g14_irr || g14_irr_l || g14_irr_u;
	blah15 = g15_log_irr || var_g15 || se_g15 || g15_irr || g15_irr_l || g15_irr_u;
	blah16 = g16_log_irr || var_g16 || se_g16 || g16_irr || g16_irr_l || g16_irr_u;
	blah17 = g17_log_irr || var_g17 || se_g17 || g17_irr || g17_irr_l || g17_irr_u;
	blah18 = g18_log_irr || var_g18 || se_g18 || g18_irr || g18_irr_l || g18_irr_u;
	blah19 = g19_log_irr || var_g19 || se_g19 || g19_irr || g19_irr_l || g19_irr_u;
	blah20 = g20_log_irr || var_g20 || se_g20 || g20_irr || g20_irr_l || g20_irr_u;
	blah21 = g21_log_irr || var_g21 || se_g21 || g21_irr || g21_irr_l || g21_irr_u;
	blah22 = g22_log_irr || var_g22 || se_g22 || g22_irr || g22_irr_l || g22_irr_u;
	blah23 = g23_log_irr || var_g23 || se_g23 || g23_irr || g23_irr_l || g23_irr_u;
	blah24 = g24_log_irr || var_g24 || se_g24 || g24_irr || g24_irr_l || g24_irr_u;

	stuff = blah1 // blah2 // blah3 // blah4 // blah5 // blah6 // blah7 // blah8 // blah9 // blah10 // blah11 // blah12 // blah13 // blah14 // blah15 // blah16
				// blah17 // blah18 // blah19 // blah20 // blah21 // blah22 // blah23 // blah24;

	name1 = "Transformation";
	labels= "Lead: 2 vs 1" || "Lead: 3 vs 1" || "Lead: 4 vs 1" || "Sex: M vs F" || "Race: B vs. W" || "Race: MEX vs. W" || "Race: Oth vs. W" || "Age: 3 vs. 2" || "Age: 4 vs. 2"
				|| "Age: 5 vs. 2" || "Rural vs. Urban" || "Region: S vs. NE" || "Region: W vs. NE" || "Region: MW vs. NE" || "Below vs. Above Poverty" || "Education: Less HS vs HS"
				|| "Education: More HS vs HS" || "Smoking HH: Yes vs No" || "BW: Low vs Normal" || "BW: High vs Normal" || "BF: Yes vs No" || "Been Dentist: Yes vs No"
				|| "Condition: VG/G vs Exc" || "Condition: F/P vs Exc";
	labels2 = labels`;

	names = "Log-IRR" || "Variance" || "Std Err" || "IRR" || "IRR LCI" || "IRR UCI"; 

	print "Delta Method Results (dft--Full Model):",, labels2[colname=name1] stuff[colname = names];
run;quit;
ods pdf close;
